@@ -1,4 +1,3 @@
-
 include("script/campaign/libcampaign.js");
 include("script/campaign/templates.js");
 
@@ -6,13 +5,20 @@ const mis_newParadigmRes = [
 	"R-Wpn-MG1Mk1", "R-Vehicle-Body01", "R-Sys-Spade1Mk1", "R-Vehicle-Prop-Wheels",
 	"R-Sys-Engineering01", "R-Wpn-MG-Damage03", "R-Wpn-MG-ROF01", "R-Wpn-Cannon-Damage02",
 	"R-Wpn-Flamer-Damage03", "R-Wpn-Flamer-Range01", "R-Wpn-Flamer-ROF01",
-	"R-Defense-WallUpgrade03", "R-Struc-Materials03", "R-Vehicle-Engine02",
+	"R-Defense-WallUpgrade02", "R-Struc-Materials02", "R-Vehicle-Engine02",
 	"R-Struc-RprFac-Upgrade02", "R-Wpn-Rocket-Damage01", "R-Wpn-Rocket-ROF03",
 	"R-Vehicle-Metals01", "R-Wpn-Mortar-Damage02", "R-Wpn-Rocket-Accuracy01",
 	"R-Wpn-RocketSlow-Damage01", "R-Wpn-Mortar-ROF01",
 ];
+const mis_newParadigmResClassic = [
+	"R-Defense-WallUpgrade01", "R-Struc-Factory-Upgrade01", "R-Struc-Materials01",
+	"R-Vehicle-Metals02", "R-Vehicle-Engine01", "R-Wpn-Cannon-Damage02",
+	"R-Wpn-Flamer-Damage03", "R-Wpn-MG-Damage03", "R-Wpn-Rocket-Damage02",
+	"R-Wpn-Mortar-Damage01", "R-Wpn-MG-ROF01", "R-Wpn-Rocket-Accuracy01",
+];
 const mis_landingZoneList = [ "NPLZ1", "NPLZ2", "NPLZ3", "NPLZ4", "NPLZ5" ];
 const mis_landingZoneMessages = [ "C1CA_LZ1", "C1CA_LZ2", "C1CA_LZ3", "C1CA_LZ4", "C1CA_LZ5" ];
+const MIN_TRANSPORT_RUNS = 10;
 var blipActive;
 var lastLZ, lastHeavy;
 var totalTransportLoads;
@@ -50,7 +56,6 @@ function baseEstablished()
 // a simple extra victory condition callback
 function extraVictoryCondition()
 {
-	const MIN_TRANSPORT_RUNS = 10;
 	const enemies = enumArea(0, 0, mapWidth, mapHeight, ENEMIES, false);
 	// No enemies on map and at least eleven New Paradigm transport runs.
 	if (baseEstablished() && (totalTransportLoads > MIN_TRANSPORT_RUNS) && !enemies.length)
@@ -94,20 +99,29 @@ function sendTransport()
 	lastLZ = picked.idx;
 	const pos = camMakePos(picked.label);
 
-	// (2 or 3 or 4) pairs of each droid template.
+	// (2, 3, 4, or 5) pairs of each droid template.
 	// This emulates wzcam's droid count distribution.
-	const COUNT = [ 2, 3, 4, 4, 4, 4, 4, 4, 4 ][camRand(9)];
+	const unitDistribution = ((camClassicMode()) ? [2, 3, 4, 4, 4, 4, 4, 4, 4] : [4, 4, 4, 5, 5]);
+	const COUNT = unitDistribution[camRand(unitDistribution.length)];
 
 	let templates;
 	if (lastHeavy)
 	{
 		lastHeavy = false;
 		templates = [ cTempl.nppod, cTempl.nphmg, cTempl.npmrl, cTempl.npsmc, cTempl.npltat ];
+		if (camClassicMode())
+		{
+			templates.pop();
+		}
 	}
 	else
 	{
 		lastHeavy = true;
 		templates = [ cTempl.npsmct, cTempl.npmor, cTempl.npsmc, cTempl.npmmct, cTempl.npmrl, cTempl.nphmg, cTempl.npsbb, cTempl.npltat ];
+		if (camClassicMode())
+		{
+			templates.pop();
+		}
 	}
 
 	const droids = [];
@@ -115,8 +129,8 @@ function sendTransport()
 	{
 		const t = templates[camRand(templates.length)];
 		// two droids of each template
-		droids[droids.length] = t;
-		droids[droids.length] = t;
+		droids.push(t);
+		droids.push(t);
 	}
 
 	camSendReinforcement(CAM_NEW_PARADIGM, pos, droids, CAM_REINFORCE_TRANSPORT, {
@@ -130,6 +144,18 @@ function sendTransport()
 	totalTransportLoads += 1;
 }
 
+function insaneReinforcementSpawn()
+{
+	if (totalTransportLoads > MIN_TRANSPORT_RUNS)
+	{
+		return;
+	}
+	const units = [cTempl.npltat, cTempl.npmrl, cTempl.npmmct, cTempl.nphmg];
+	const limits = {minimum: 10, maxRandom: 4};
+	const location = ["reinforceNorth", "reinforceNorthEast"];
+	camSendGenericSpawn(CAM_REINFORCE_GROUND, CAM_NEW_PARADIGM, CAM_REINFORCE_CONDITION_NONE, location, units, limits.minimum, limits.maxRandom);
+}
+
 function startTransporterAttack()
 {
 	let attackTime = camMinutesToMilliseconds(2.2);
@@ -148,27 +174,30 @@ function eventStartLevel()
 	totalTransportLoads = 0;
 	blipActive = false;
 
-	camSetStandardWinLossConditions(CAM_VICTORY_STANDARD, "SUB_1_4AS", {
+	camSetStandardWinLossConditions(CAM_VICTORY_STANDARD, cam_levels.alpha8.pre, {
 		callback: "extraVictoryCondition"
 	});
 	const startPos = getObject("startPosition");
 	const lz = getObject("landingZone");
 	centreView(startPos.x, startPos.y);
 	setNoGoArea(lz.x, lz.y, lz.x2, lz.y2, CAM_HUMAN_PLAYER);
-	camCompleteRequiredResearch(mis_newParadigmRes, CAM_NEW_PARADIGM);
 
-	// make sure player doesn't build on enemy LZs
-	for (let i = 1; i <= 5; ++i)
+	if (camClassicMode())
 	{
-		const ph = getObject("PhantomLZ" + i);
-		// HACK: set LZs of bad players, namely 2...6,
-		// note: player 1 is NP
-		setNoGoArea(ph.x, ph.y, ph.x2, ph.y2, i + 2);
+		camClassicResearch(mis_newParadigmResClassic, CAM_NEW_PARADIGM);
+	}
+	else
+	{
+		camCompleteRequiredResearch(mis_newParadigmRes, CAM_NEW_PARADIGM);
 	}
 
-	setMissionTime(camChangeOnDiff(camMinutesToSeconds(30)));
+	camSetMissionTimer(camChangeOnDiff(camMinutesToSeconds(30)));
 	camPlayVideos({video: "MB1CA_MSG", type: CAMP_MSG});
 
 	// first transport after 10 seconds
 	queue("startTransporterAttack", camSecondsToMilliseconds(10));
+	if (camAllowInsaneSpawns())
+	{
+		setTimer("insaneReinforcementSpawn", camMinutesToMilliseconds(1.5));
+	}
 }
