@@ -10,15 +10,11 @@ function setupGame()
 	else if (tilesetType === "URBAN")
 	{
 		setCampaignNumber(2);
-		replaceTexture("page-8-player-buildings-bases.png", "page-8-player-buildings-bases-urban.png");
-		replaceTexture("page-9-player-buildings-bases.png", "page-9-player-buildings-bases-urban.png");
 		replaceTexture("page-7-barbarians-arizona.png", "page-7-barbarians-urban.png");
 	}
 	else if (tilesetType === "ROCKIES")
 	{
 		setCampaignNumber(3);
-		replaceTexture("page-8-player-buildings-bases.png", "page-8-player-buildings-bases-rockies.png");
-		replaceTexture("page-9-player-buildings-bases.png", "page-9-player-buildings-bases-rockies.png");
 		replaceTexture("page-7-barbarians-arizona.png", "page-7-barbarians-kevlar.png");
 		// for some reason rockies will use arizona babas
 	}
@@ -34,7 +30,10 @@ function setupGame()
 	// Enable all templates
 	setDesign(true);
 
+	// Enable all guide topics
+	addGuideTopic("wz2100::**");
+
 	showInterface(); // init buttons. This MUST come before setting the reticule button data
-	setMainReticule();
+	queue("setMainReticule", TICK_TIME);
 	mainReticule = true;
 }
