@@ -2,14 +2,14 @@
 //for anti-cyborg measures.
 function switchOffMG()
 {
-	let cyborgThreat = playerCyborgRatio(getMostHarmfulPlayer()) >= subPersonalities[personality].cyborgThreatPercentage;
+	const __cyborgThreat = playerCyborgRatio(getMostHarmfulPlayer()) >= subPersonalities[personality].cyborgThreatPercentage;
 	// Will keep using machineguns until the basic laser is available or if the personality
 	// doesn't have the first of its primary weapon or artillery line available.
-	if ((cyborgThreat || !havePrimaryOrArtilleryWeapon()) && !componentAvailable("Laser3BEAMMk1"))
+	if ((__cyborgThreat || !havePrimaryOrArtilleryWeapon()) && !componentAvailable("Laser3BEAMMk1"))
 	{
 		turnOffMG = false;
 	}
-	else if (getMultiTechLevel() === 1 && gameTime <= 600000)
+	else if (!strangeStartSettingOver() || ((getMultiTechLevel() === 1) && gameTime <= 600000))
 	{
 		turnOffMG = false;
 	}
@@ -33,7 +33,7 @@ function playerCyborgRatio(player)
 
 	function uncached(player)
 	{
-		return enumDroid(player, DROID_CYBORG).length / (enumDroid(player).length + 1);
+		return enumDroid(player, DROID_CYBORG).length / (countDroid(DROID_ANY, player) + 1);
 	}
 
 	return cacheThis(uncached, [player], "playerCyborgRatio" + player, 8000);
@@ -44,16 +44,18 @@ function countEnemyVTOL(player)
 {
 	function uncached(player)
 	{
-		let enemies = isDefined(player) ? [player] : findLivingEnemies();
+		const _enemies = isDefined(player) ? [player] : findLivingEnemies();
 		let enemyVtolCount = 0;
 
-		for (let x = 0, e = enemies.length; x < e; ++x)
+		for (let x = 0, e = _enemies.length; x < e; ++x)
 		{
-			let playerDroids = enumDroid(enemies[x]);
-			for (let c = 0, l = playerDroids.length; c < l; ++c)
+			const _playerDroids = enumDroid(_enemies[x]);
+
+			for (let c = 0, l = _playerDroids.length; c < l; ++c)
 			{
-				let prop = playerDroids[c].propulsion;
-				if (prop === "V-Tol" || prop === "Helicopter")
+				const __prop = _playerDroids[c].propulsion;
+
+				if (__prop === "V-Tol" || __prop === "Helicopter")
 				{
 					++enemyVtolCount;
 				}
@@ -75,7 +77,7 @@ function playerVtolRatio(player)
 
 	function uncached(player)
 	{
-		return countEnemyVTOL(player) / (enumDroid(player).length + 1);
+		return countEnemyVTOL(player) / (countDroid(DROID_ANY, player) + 1);
 	}
 
 	return cacheThis(uncached, [player], "playerVtolRatio" + player, 6000);
@@ -90,7 +92,7 @@ function playerStructureUnitRatio(player)
 
 	function uncached(player)
 	{
-		return enumStruct(player).length / (enumDroid(player).length + 1);
+		return enumStruct(player).length / (countDroid(DROID_ANY, player) + 1);
 	}
 
 	return cacheThis(uncached, [player], "playerStructureUnitRatio" + player, 30000);
@@ -108,29 +110,30 @@ function playerBodySizeRatio(player)
 		let small = 0;
 		let medium = 0;
 		let heavy = 0;
-		let attackers = enumDroid(player, DROID_WEAPON);
-		for (let i = 0, len = attackers.length; i < len; ++i)
-		{
-			let body = attackers[i].body;
+		const _attackers = enumDroid(player, DROID_WEAPON);
 
-			if (body === "Body1REC" || body === "Body2SUP" || body === "Body4ABT" || body === "Body3MBT")
+		for (let i = 0, len = _attackers.length; i < len; ++i)
+		{
+			const __body = _attackers[i].body;
+
+			if (__body === "Body1REC" || __body === "Body2SUP" || __body === "Body4ABT" || __body === "Body3MBT")
 			{
 				++small;
 			}
-			else if (body === "Body5REC" || body === "Body6SUPP" || body === "Body8MBT" || body === "Body7ABT")
+			else if (__body === "Body5REC" || __body === "Body6SUPP" || __body === "Body8MBT" || __body === "Body7ABT")
 			{
 				++medium;
 			}
-			else if (body === "Body11ABT" || body === "Body9REC" || body === "Body13SUP" || body === "Body14SUP" || body === "Body12SUP" || body === "Body10MBT")
+			else if (__body === "Body11ABT" || __body === "Body9REC" || __body === "Body13SUP" || __body === "Body14SUP" || __body === "Body12SUP" || __body === "Body10MBT")
 			{
 				++heavy;
 			}
 		}
 
 		return {
-			small: small / (attackers.length + 1),
-			medium: medium / (attackers.length + 1),
-			heavy: heavy / (attackers.length + 1),
+			small: small / (_attackers.length + 1),
+			medium: medium / (_attackers.length + 1),
+			heavy: heavy / (_attackers.length + 1),
 		};
 	}
 
@@ -150,34 +153,35 @@ function playerLandPropRatio(player)
 		let halftrack = 0;
 		let track = 0;
 		let hover = 0;
-		let attackers = enumDroid(player, DROID_WEAPON);
-		for (let i = 0, len = attackers.length; i < len; ++i)
-		{
-			let prop = attackers[i].propulsion;
+		const _attackers = enumDroid(player, DROID_WEAPON);
 
-			if (prop === "wheeled01")
+		for (let i = 0, len = _attackers.length; i < len; ++i)
+		{
+			const __prop = _attackers[i].propulsion;
+
+			if (__prop === "wheeled01")
 			{
 				++wheel;
 			}
-			else if (prop === "HalfTrack")
+			else if (__prop === "HalfTrack")
 			{
 				++halftrack;
 			}
-			else if (prop === "tracked01")
+			else if (__prop === "tracked01")
 			{
 				++track;
 			}
-			else if (prop === "hover01")
+			else if (__prop === "hover01")
 			{
 				++hover;
 			}
 		}
 
 		return {
-			wheel: wheel / (attackers.length + 1),
-			halftrack: halftrack / (attackers.length + 1),
-			track: track / (attackers.length + 1),
-			hover: hover / (attackers.length + 1),
+			wheel: wheel / (_attackers.length + 1),
+			halftrack: halftrack / (_attackers.length + 1),
+			track: track / (_attackers.length + 1),
+			hover: hover / (_attackers.length + 1),
 		};
 	}
 
@@ -210,20 +214,21 @@ function myPersonality()
 //Semi-randomly choose a personality. Called from eventStartLevel().
 function adaptToMap()
 {
-	const HIGH_TECH_LEVEL = getMultiTechLevel() >= 2;
-	const FRIEND_COUNT = playerAlliance(true).length;
-	let highOil = highOilMap();
+	const __highTechLevel = (getMultiTechLevel() >= 2);
+	const __friendCount = playerAlliance(true).length;
+	const __highOil = highOilMap();
 	let personal;
 	let chosen;
 
 	//Map to allow a higher chance for a specific personality to be chosen.
-	if (HIGH_TECH_LEVEL || highOil)
+	if (__highTechLevel || __highOil)
 	{
 		personal = [
-			"AR", "AR", "AR", "AR", "AR",
-			"AB", "AB", "AB", "AB", "AB", "AB", "AB", "AB", "AB",
+			"AR", "AR",
+			"AB", "AB", "AB", "AB", "AB", "AB", "AB",
 			"AC", "AC", "AC", "AC", "AC", "AC", "AC", "AC", "AC",
-			"AA", "AA", "AA",
+			"AA", "AA", "AA", "AA",
+			"AV", "AV", "AV", "AV", "AV", "AV"
 		];
 	}
 	else
@@ -234,23 +239,24 @@ function adaptToMap()
 			"AB", "AB", "AB", "AB", "AB", "AB", "AB",
 			"AC", "AC", "AC", "AC", "AC", "AC", "AC",
 			"AA", "AA",
+			"AV", "AV", "AV"
 		];
 	}
 
 	chosen = personal[random(personal.length)];
 
 	//Some personalities should only be chosen if accompanied by a friend
-	while ((subPersonalities[chosen].canPlayBySelf === false) && (FRIEND_COUNT === 0))
+	while ((subPersonalities[chosen].canPlayBySelf === false) && !__friendCount)
 	{
 		chosen = personal[random(personal.length)];
 	}
 
 	//Offensive is better for high oil
-	if (highOil)
+	if (__highOil && subPersonalities[chosen].allowAutomaticPersonalityOverride)
 	{
 		subPersonalities[chosen].resPath = "offensive";
 
-		if ((HIGH_TECH_LEVEL || (baseType >= CAMP_BASE)) && random(100) < 33)
+		if ((__highTechLevel || (baseType >= CAMP_BASE)) && chance(33))
 		{
 			subPersonalities[chosen].resPath = "air";
 		}
