@@ -9,7 +9,8 @@
 
 // slightly shift all timers so that not to get too many of them on the same game frame,
 // especially when multiple AI instances are running
-function rnd() {
+function rnd()
+{
 	return random(201) - 100;
 }
 
@@ -19,9 +20,12 @@ _global.setTimers = function() {
 	setTimer("checkAttack", 100);
 	setTimer("adaptCycle", 100);
 	setTimer("rebalanceGroups", 10000 + 20 * rnd());
+
 	if (difficulty === EASY)
+	{
 		setTimer("goEasy", 30000);
-}
+	}
+};
 
 ////////////////////////////////////////////////////////////////////////////////////////////
 })(this);
