@@ -25,6 +25,7 @@ function eventDroidBuilt(droid, struct)
 		{
 			groupAdd(baseBuilders, droid);
 		}
+
 		checkLocalJobs();
 	}
 }
@@ -41,7 +42,8 @@ function eventAttacked(victim, attacker)
 		//Flee if we are outnumbered to an extent
 		if (victim.type === DROID && victim.player === me)
 		{
-			var seenEnemyGroupSize = enumRange(victim.x, victim.y, GROUP_SCAN_RADIUS, ENEMIES, false).length;
+			const seenEnemyGroupSize = enumRange(victim.x, victim.y, GROUP_SCAN_RADIUS, ENEMIES, false).length;
+
 			if (isVTOL(victim))
 			{
 				vtolReady(victim.id); //check if it needs repair or rearming
@@ -55,7 +57,8 @@ function eventAttacked(victim, attacker)
 			}
 		}
 
-		var enemyNumber = getCurrentEnemy();
+		const enemyNumber = getCurrentEnemy();
+
 		if (!defined(enemyNumber))
 		{
 			return;
@@ -74,20 +77,23 @@ function eventAttacked(victim, attacker)
 			enemyHasVtol = true; //Definitely has VTOLs.
 			return; //Ignore VTOLs
 		}
+
 		if (ThrottleThis("eventAttacked_Throttle_1", 1500))
 		{
 			return;
 		}
 
 		//log("Defend!");
-		var loc = {x: attacker.x, y: attacker.y };
-		var defenders = enumGroup(attackGroup);
-		var defLen = defenders.length;
+		const loc = {x: attacker.x, y: attacker.y };
+		const defenders = enumGroup(attackGroup);
+		const defLen = defenders.length;
+
 		if (defLen > MIN_GROUND_UNITS)
 		{
 			for (let i = 0; i < defLen; ++i)
 			{
-				var dr = defenders[i];
+				const dr = defenders[i];
+
 				if (dr.order !== DORDER_RECYCLE && !droidNeedsRepair(dr.id) && dr.id !== victim.id)
 				{
 					orderDroidLoc(dr, DORDER_SCOUT, loc.x, loc.y);
@@ -95,13 +101,15 @@ function eventAttacked(victim, attacker)
 			}
 		}
 
-		var vtols = enumGroup(vtolGroup);
-		var vtolLen = vtols.length;
+		const vtols = enumGroup(vtolGroup);
+		const vtolLen = vtols.length;
+
 		if (vtolLen > MIN_VTOL_UNITS)
 		{
 			for (let j = 0; j < vtolLen; ++j)
 			{
-				var vt = vtols[j];
+				const vt = vtols[j];
+
 				if (vtolReady(vt.id))
 				{
 					orderDroidLoc(vt, DORDER_SCOUT, loc.x, loc.y);
@@ -149,7 +157,8 @@ function eventStartLevel()
 function eventStructureBuilt(structure, droid)
 {
 	//don't go crazy defending stuff we just built relavtively close to the base.
-	var dist = distBetweenTwoPoints(BASE.x, BASE.y, structure.x, structure.y);
+	const dist = distBetweenTwoPoints(BASE.x, BASE.y, structure.x, structure.y);
+
 	if (!droid || dist <= AVG_BASE_RADIUS)
 	{
 		return;
@@ -163,7 +172,7 @@ function eventDroidIdle(droid)
 	if (droid.droidType === DROID_CONSTRUCT)
 	{
 		const ENEMY_DERRICK_SCAN_RANGE = 4;
-		var enemyDerrs = enumRange(droid.x, droid.y, ENEMY_DERRICK_SCAN_RANGE, ENEMIES, false).filter(isDerrick);
+		const enemyDerrs = enumRange(droid.x, droid.y, ENEMY_DERRICK_SCAN_RANGE, ENEMIES, false).filter(isDerrick);
 
 		//most likely an enemy truck got the oil before us, so try to build a defense near it.
 		if (enemyDerrs.length > 0)
@@ -180,12 +189,14 @@ function eventBeacon(x, y, from, to, message)
 	{
 		//log(from + " sent a beacon. Location [" + x + ", " + y + "]");
 		const BEACON_SCAN_RADIUS = 4;
-		var enemyObjects = enumRange(x, y, BEACON_SCAN_RADIUS, ENEMIES, false);
+		const enemyObjects = enumRange(x, y, BEACON_SCAN_RADIUS, ENEMIES, false);
+
 		if (enemyObjects.length > 0)
 		{
 			for (let i = 0, l = enemyObjects.length; i < l; ++i)
 			{
-				var obj = enemyObjects[i];
+				const obj = enemyObjects[i];
+
 				if (obj)
 				{
 					setPlayerAsTarget(obj.player);
