@@ -753,6 +753,7 @@ namespace gfx_api
 		glm::mat4 ViewMatrix;
 		glm::mat4 ModelUVLightmapMatrix;
 		glm::mat4 ShadowMapMVPMatrix[WZ_MAX_SHADOW_CASCADES];
+		glm::vec4 cameraPos; // in modelSpace
 		glm::vec4 sunPos;
 		glm::vec4 sceneColor;
 		glm::vec4 ambient;
@@ -927,17 +928,9 @@ namespace gfx_api
 	struct constant_buffer_type<SHADER_TERRAIN_DEPTHMAP>
 	{
 		glm::mat4 transform_matrix;
-//		glm::vec4 paramX;
-//		glm::vec4 paramY;
-//		glm::vec4 paramXLight;
-//		glm::vec4 paramYLight;
-//		glm::mat4 unused;
-//		glm::mat4 texture_matrix;
-//		glm::vec4 fog_colour;
 		int fog_enabled;
 		float fog_begin;
 		float fog_end;
-//		int texture0;
 	};
 
 	using TerrainDepthOnlyForDepthMap = typename gfx_api::pipeline_state_helper<rasterizer_state<REND_OPAQUE, DEPTH_CMP_LEQ_WRT_ON, 0, polygon_offset::disabled, stencil_mode::stencil_disabled, cull_mode::none>, primitive_type::triangles, index_type::u32,
@@ -946,54 +939,6 @@ namespace gfx_api
 		TerrainVertexVBODescription
 	>, std::tuple<texture_description<0, sampler_type::bilinear_repeat>>, SHADER_TERRAIN_DEPTHMAP>;
 
-	template<>
-	struct constant_buffer_type<SHADER_TERRAIN>
-	{
-		glm::mat4 transform_matrix;
-		glm::vec4 paramX;
-		glm::vec4 paramY;
-		glm::vec4 paramXLight;
-		glm::vec4 paramYLight;
-		glm::mat4 unused;
-		glm::mat4 texture_matrix;
-		glm::vec4 fog_colour;
-		int fog_enabled;
-		float fog_begin;
-		float fog_end;
-		int texture0;
-		int texture1;
-	};
-
-	using TerrainLayer = typename gfx_api::pipeline_state_helper<rasterizer_state<REND_ADDITIVE, DEPTH_CMP_LEQ_WRT_OFF, 255, polygon_offset::disabled, stencil_mode::stencil_disabled, cull_mode::back>, primitive_type::triangles, index_type::u32,
-	std::tuple<constant_buffer_type<SHADER_TERRAIN>>,
-	std::tuple<
-	TerrainVertexVBODescription,
-	vertex_buffer_description<4, gfx_api::vertex_attribute_input_rate::vertex, vertex_attribute_description<color, gfx_api::vertex_attribute_type::u8x4_norm, 0>>
-	>, std::tuple<texture_description<0, sampler_type::anisotropic_repeat>, texture_description<1, sampler_type::bilinear>>, SHADER_TERRAIN>;
-
-	template<>
-	struct constant_buffer_type<SHADER_DECALS>
-	{
-		glm::mat4 transform_matrix;
-		glm::mat4 texture_matrix;
-		glm::vec4 param1;
-		glm::vec4 param2;
-		glm::vec4 fog_colour;
-		int fog_enabled;
-		float fog_begin;
-		float fog_end;
-		int texture0;
-		int texture1;
-	};
-
-	using TerrainDecals = typename gfx_api::pipeline_state_helper<rasterizer_state<REND_ALPHA, DEPTH_CMP_LEQ_WRT_OFF, 255, polygon_offset::disabled, stencil_mode::stencil_disabled, cull_mode::back>, primitive_type::triangles, index_type::u16,
-	std::tuple<constant_buffer_type<SHADER_DECALS>>,
-	std::tuple<
-	vertex_buffer_description<sizeof(glm::vec3) + sizeof(glm::vec2), gfx_api::vertex_attribute_input_rate::vertex,
-	vertex_attribute_description<position, gfx_api::vertex_attribute_type::float3, 0>,
-	vertex_attribute_description<texcoord, gfx_api::vertex_attribute_type::float2, sizeof(glm::vec3)>
-	>
-	>, std::tuple<texture_description<0, sampler_type::anisotropic>, texture_description<1, sampler_type::bilinear>>, SHADER_DECALS>;
 
 	struct TerrainDecalVertex
 	{
