@@ -21,7 +21,17 @@
 
 #include "gfx_api.h"
 
+#if defined(__EMSCRIPTEN__)
+# define WZ_STATIC_GL_BINDINGS
+#endif
+
+#if !defined(__EMSCRIPTEN__) || !defined(WZ_STATIC_GL_BINDINGS)
 #include <glad/glad.h>
+#else
+// Emscripten uses static linking for performance
+#include <GLES3/gl3.h>
+typedef void* (* GLADloadproc)(const char *name);
+#endif
 #include <algorithm>
 #include <cmath>
 #include <functional>
@@ -63,6 +73,8 @@ private:
 	size_t mip_count = 0;
 	gfx_api::pixel_format internal_format = gfx_api::pixel_format::invalid;
 	bool gles = false;
+	size_t tex_width = 0;
+	size_t tex_height = 0;
 #if defined(WZ_DEBUG_GFX_API_LEAKS)
 	std::string debugName;
 #endif
@@ -76,8 +88,9 @@ public:
 	virtual bool upload(const size_t& mip_level, const iV_BaseImage& image) override;
 	virtual bool upload_sub(const size_t& mip_level, const size_t& offset_x, const size_t& offset_y, const iV_Image& image) override;
 	virtual unsigned id() override;
+	virtual gfx_api::texture2dDimensions get_dimensions() const override;
 private:
-	virtual bool upload_internal(const size_t& mip_level, const size_t& offset_x, const size_t& offset_y, const iV_BaseImage& image);
+	bool upload_internal(const size_t& mip_level, const size_t& offset_x, const size_t& offset_y, const iV_BaseImage& image);
 };
 
 struct texture_array_mip_level_buffer; // forward-declare
@@ -106,7 +119,7 @@ public:
 	virtual bool upload_layer(const size_t& layer, const size_t& mip_level, const iV_BaseImage& image) override;
 	virtual unsigned id() override;
 private:
-	virtual bool upload_internal(const size_t& layer, const size_t& mip_level, const size_t& offset_x, const size_t& offset_y, const iV_BaseImage& image);
+	bool upload_internal(const size_t& layer, const size_t& mip_level, const size_t& offset_x, const size_t& offset_y, const iV_BaseImage& image);
 };
 
 struct gl_gpurendered_texture final : public gfx_api::abstract_texture
@@ -162,6 +175,8 @@ public:
 	~gl_pipeline_id() {}
 };
 
+struct gl_context;
+
 struct gl_pipeline_state_object final : public gfx_api::pipeline_state_object
 {
 	gfx_api::state_description desc;
@@ -172,6 +187,7 @@ struct gl_pipeline_state_object final : public gfx_api::pipeline_state_object
 	std::vector<GLint> locations;
 	std::vector<GLint> duplicateFragmentUniformLocations;
 	bool hasSpecializationConstant_ShadowConstants = false;
+	bool hasSpecializationConstants_PointLights = false;
 
 	std::vector<std::function<void(const void*, size_t)>> uniform_bind_functions;
 
@@ -181,7 +197,7 @@ struct gl_pipeline_state_object final : public gfx_api::pipeline_state_object
 	template<typename T>
 	typename std::pair<std::type_index, std::function<void(const void*, size_t)>> uniform_setting_func();
 
-	gl_pipeline_state_object(bool gles, bool fragmentHighpFloatAvailable, bool fragmentHighpIntAvailable, bool patchFragmentShaderMipLodBias, const gfx_api::pipeline_create_info& createInfo, optional<float> mipLodBias, const gfx_api::shadow_constants& shadowConstants);
+	gl_pipeline_state_object(gl_context& ctx, bool fragmentHighpFloatAvailable, bool fragmentHighpIntAvailable, bool patchFragmentShaderMipLodBias, const gfx_api::pipeline_create_info& createInfo, optional<float> mipLodBias, const gfx_api::lighting_constants& shadowConstants);
 	~gl_pipeline_state_object();
 	void set_constants(const void* buffer, const size_t& size);
 	void set_uniforms(const size_t& first, const std::vector<std::tuple<const void*, size_t>>& uniform_blocks);
@@ -202,13 +218,14 @@ private:
 
 	void getLocs(const std::vector<std::tuple<std::string, GLint>> &samplersToBind);
 
-	void build_program(bool fragmentHighpFloatAvailable, bool fragmentHighpIntAvailable, bool patchFragmentShaderMipLodBias,
+	void build_program(gl_context& ctx,
+					   bool fragmentHighpFloatAvailable, bool fragmentHighpIntAvailable, bool patchFragmentShaderMipLodBias,
 					   const std::string& programName,
 					   const char * vertex_header, const std::string& vertexPath,
 					   const char * fragment_header, const std::string& fragmentPath,
 					   const std::vector<std::string> &uniformNames,
 					   const std::vector<std::tuple<std::string, GLint>> &samplersToBind,
-					   optional<float> mipLodBias, const gfx_api::shadow_constants& shadowConstants);
+					   optional<float> mipLodBias, const gfx_api::lighting_constants& shadowConstants);
 
 	void fetch_uniforms(const std::vector<std::string>& uniformNames, const std::vector<std::string>& duplicateFragmentUniforms, const std::string& programName);
 
@@ -226,6 +243,13 @@ private:
 	void setUniforms(size_t uniformIdx, const float &v);
 
 	void setUniforms(size_t uniformIdx, const ::glm::mat4 *m, size_t count);
+	void setUniforms(size_t uniformIdx, const ::glm::vec4* m, size_t count);
+	template<typename T, size_t count>
+	void setUniforms(size_t uniformIdx, const std::array<T, count>& m)
+	{
+		setUniforms(uniformIdx, m.data(), count);
+	}
+	void setUniforms(size_t uniformIdx, const ::glm::ivec4* m, size_t count);
 	void setUniforms(size_t uniformIdx, const float *v, size_t count);
 
 	// Wish there was static reflection in C++...
@@ -236,10 +260,8 @@ private:
 	void set_constants(const gfx_api::Draw3DShapeInstancedPerMeshUniforms& cbuf);
 	void set_constants(const gfx_api::Draw3DShapeInstancedDepthOnlyGlobalUniforms& cbuf);
 
-	void set_constants(const gfx_api::constant_buffer_type<SHADER_TERRAIN>& cbuf);
 	void set_constants(const gfx_api::constant_buffer_type<SHADER_TERRAIN_DEPTH>& cbuf);
 	void set_constants(const gfx_api::constant_buffer_type<SHADER_TERRAIN_DEPTHMAP>& cbuf);
-	void set_constants(const gfx_api::constant_buffer_type<SHADER_DECALS>& cbuf);
 	void set_constants(const gfx_api::TerrainCombinedUniforms& cbuf);
 	void set_constants(const gfx_api::constant_buffer_type<SHADER_WATER>& cbuf);
 	void set_constants(const gfx_api::constant_buffer_type<SHADER_WATER_HIGH>& cbuf);
@@ -267,7 +289,7 @@ struct gl_context final : public gfx_api::context
 	size_t scratchbuffer_size = 0;
 	bool khr_debug = false;
 	optional<float> mipLodBias;
-	gfx_api::shadow_constants shadowConstants;
+	gfx_api::lighting_constants shadowConstants;
 
 	bool gles = false;
 	bool fragmentHighpFloatAvailable = true;
@@ -323,26 +345,30 @@ struct gl_context final : public gfx_api::context
 	virtual bool getScreenshot(std::function<void (std::unique_ptr<iV_Image>)> callback) override;
 	virtual void handleWindowSizeChange(unsigned int oldWidth, unsigned int oldHeight, unsigned int newWidth, unsigned int newHeight) override;
 	virtual std::pair<uint32_t, uint32_t> getDrawableDimensions() override;
+	bool isYAxisInverted() const override { return false; }
 	virtual bool shouldDraw() override;
 	virtual void shutdown() override;
 	virtual const size_t& current_FrameNum() const override;
-	virtual bool setSwapInterval(gfx_api::context::swap_interval_mode mode) override;
+	virtual bool setSwapInterval(gfx_api::context::swap_interval_mode mode, const SetSwapIntervalCompletionHandler& completionHandler) override;
 	virtual gfx_api::context::swap_interval_mode getSwapInterval() const override;
 	virtual bool textureFormatIsSupported(gfx_api::pixel_format_target target, gfx_api::pixel_format format, gfx_api::pixel_format_usage::flags usage) override;
 	virtual bool supportsMipLodBias() const override;
 	virtual bool supports2DTextureArrays() const override;
 	virtual bool supportsIntVertexAttributes() const override;
 	virtual size_t maxFramesInFlight() const override;
-	virtual gfx_api::shadow_constants getShadowConstants() override;
-	virtual bool setShadowConstants(gfx_api::shadow_constants values) override;
+	virtual gfx_api::lighting_constants getShadowConstants() override;
+	virtual bool setShadowConstants(gfx_api::lighting_constants values) override;
 	// instanced rendering APIs
 	virtual bool supportsInstancedRendering() override;
 	virtual void draw_instanced(const std::size_t& offset, const std::size_t &count, const gfx_api::primitive_type &primitive, std::size_t instance_count) override;
 	virtual void draw_elements_instanced(const std::size_t& offset, const std::size_t& count, const gfx_api::primitive_type& primitive, const gfx_api::index_type& index, std::size_t instance_count) override;
+	// debug apis for recompiling pipelines
+	virtual bool debugRecompileAllPipelines() override;
 private:
 	virtual bool _initialize(const gfx_api::backend_Impl_Factory& impl, int32_t antialiasing, swap_interval_mode mode, optional<float> mipLodBias, uint32_t depthMapResolution) override;
 	void initPixelFormatsSupport();
 	bool initInstancedFunctions();
+	bool initCheckBorderClampSupport();
 	size_t initDepthPasses(size_t resolution);
 	gl_gpurendered_texture* create_gpurendered_texture(GLenum internalFormat, GLenum format, GLenum type, const size_t& width, const size_t& height, const std::string& filename);
 	gl_gpurendered_texture* create_gpurendered_texture_array(GLenum internalFormat, GLenum format, GLenum type, const size_t& width, const size_t& height, const size_t& layer_count, const std::string& filename);
@@ -352,13 +378,23 @@ private:
 	bool createSceneRenderpass();
 	void deleteSceneRenderpass();
 	void _beginRenderPassImpl();
+
+protected:
+	friend struct gl_pipeline_state_object;
+	void wzGLObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label);
+	void wzGLPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message);
+	void wzGLPopDebugGroup();
+	bool useKHRSuffixedDebugFuncs();
+
 private:
 	bool initGLContext();
+	bool enableDebugMessageCallbacks();
 	void enableVertexAttribArray(GLuint index);
 	void disableVertexAttribArray(GLuint index);
 	std::string calculateFormattedRendererInfoString() const;
 	bool isBlocklistedGraphicsDriver() const;
 	uint32_t getSuggestedDefaultDepthBufferResolution() const;
+	bool setSwapIntervalInternal(gfx_api::context::swap_interval_mode mode);
 
 	uint32_t viewportWidth = 0;
 	uint32_t viewportHeight = 0;
@@ -368,6 +404,7 @@ private:
 	std::array<std::vector<gfx_api::pixel_format_usage::flags>, gfx_api::PIXEL_FORMAT_TARGET_COUNT> textureFormatsSupport;
 	bool has2DTextureArraySupport = false;
 	bool hasInstancedRenderingSupport = false;
+	bool hasBorderClampSupport = false;
 	int32_t maxArrayTextureLayers = 0;
 	GLfloat maxTextureAnisotropy = 0.f;
 	GLuint vaoId = 0;
