@@ -26,6 +26,7 @@
 
 #include "lib/ivis_opengl/piedraw.h"
 #include "lib/framework/frame.h"
+#include "lib/framework/pool_allocator.h"
 #include "lib/ivis_opengl/ivisdef.h"
 #include "lib/ivis_opengl/imd.h"
 #include "lib/ivis_opengl/piefunc.h"
@@ -35,17 +36,21 @@
 #include "lib/ivis_opengl/piepalette.h"
 #include "lib/ivis_opengl/pieclip.h"
 #include "lib/ivis_opengl/pieblitfunc.h"
+#include "lib/ivis_opengl/pielight_convert.h"
 #include "piematrix.h"
+#include "pielighting.h"
 #include "screen.h"
 
 #include <string.h>
 #include <vector>
 #include <algorithm>
 #include <unordered_set>
+#include <utility>
 
 #include <glm/glm.hpp>
 #include <glm/gtc/matrix_transform.hpp>
 
+
 #if defined(__clang__)
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wtautological-constant-out-of-range-compare"
@@ -245,7 +250,7 @@ void pie_BeginLighting(const Vector3f &light)
 struct ShadowcastingShape
 {
 	glm::mat4	modelViewMatrix;
-	iIMDShape	*shape;
+	const iIMDShape	*shape;
 	int		flag;
 	int		flag_data;
 	glm::vec4	light;
@@ -254,7 +259,7 @@ struct ShadowcastingShape
 struct SHAPE
 {
 	glm::mat4	modelMatrix;
-	iIMDShape	*shape;
+	const iIMDShape	*shape;
 	int		frame;
 	PIELIGHT	colour;
 	PIELIGHT	teamcolour;
@@ -520,6 +525,14 @@ static void draw3dShapeTemplated(const templatedState &lastState, ShaderOnce& gl
 	}
 }
 
+PIELIGHT straightAlphaToPremultiplied(PIELIGHT colour)
+{
+	colour.byte.r = static_cast<uint8_t>((static_cast<uint16_t>(colour.byte.r) * static_cast<uint16_t>(colour.byte.a)) / 255);
+	colour.byte.g = static_cast<uint8_t>((static_cast<uint16_t>(colour.byte.g) * static_cast<uint16_t>(colour.byte.a)) / 255);
+	colour.byte.b = static_cast<uint8_t>((static_cast<uint16_t>(colour.byte.b) * static_cast<uint16_t>(colour.byte.a)) / 255);
+	return colour;
+}
+
 static inline gfx_api::Draw3DShapePerInstanceInterleavedData GenerateInstanceData(int frame, PIELIGHT colour, PIELIGHT teamcolour, int pieFlag, int pieFlagData, glm::mat4 const &modelMatrix, float stretchDepth)
 {
 	int ecmState = (pieFlag & pie_ECM) ? 1 : 0;
@@ -534,10 +547,16 @@ static inline gfx_api::Draw3DShapePerInstanceInterleavedData GenerateInstanceDat
 		colour.byte.a = (UBYTE)pieFlagData;
 	}
 
+	if (pieFlag & pie_PREMULTIPLIED)
+	{
+		colour = straightAlphaToPremultiplied(colour);
+		teamcolour = straightAlphaToPremultiplied(teamcolour);
+	}
+
 	return gfx_api::Draw3DShapePerInstanceInterleavedData {
 		modelMatrix,
 		glm::vec4(stretchDepth, ecmState, !(pieFlag & pie_PREMULTIPLIED), float(frame)),
-		colour.rgba, teamcolour.rgba
+		colour.rgba(), teamcolour.rgba()
 	};
 }
 
@@ -941,11 +960,56 @@ static bool canInstancedMeshRendererUseInstancedRendering(bool quiet /*= false*/
 	return true;
 }
 
+template <typename Key, typename Value>
+class InsertionOrderMap
+{
+public:
+	typedef std::pair<Key, Value> Pair;
+	typedef std::vector<Pair> PairVector;
+	typedef typename PairVector::iterator iterator;
+	typedef typename PairVector::const_iterator const_iterator;
+	using ValueAllocator = typename Value::allocator_type;
+public:
+
+	explicit InsertionOrderMap(const ValueAllocator& alloc)
+		: allocator(alloc)
+	{}
+
+	Value& operator[](const Key& k)
+	{
+		auto it = keyToValuesIdxMap.find(k);
+		if (it != keyToValuesIdxMap.end())
+		{
+			return values[it->second].second;
+		}
+		auto idx = values.size();
+		values.emplace_back(k, allocator);
+		keyToValuesIdxMap[k] = idx;
+		return values[idx].second;
+	}
+	void clear() noexcept
+	{
+		values.clear();
+		keyToValuesIdxMap.clear();
+	}
+	iterator begin() noexcept { return values.begin(); }
+	iterator end() noexcept { return values.end(); }
+	const_iterator cbegin() const noexcept { return values.cbegin(); }
+	const_iterator cend() const noexcept { return values.cend(); }
+private:
+	PairVector values;
+	std::unordered_map<Key, size_t> keyToValuesIdxMap;
+	const ValueAllocator& allocator;
+};
+
 class InstancedMeshRenderer
 {
 public:
+
+	InstancedMeshRenderer();
+
 	// Queues a mesh for drawing
-	bool Draw3DShape(iIMDShape *shape, int frame, PIELIGHT teamcolour, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth);
+	bool Draw3DShape(const iIMDShape *shape, int frame, PIELIGHT teamcolour, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth);
 
 	// Finalizes queued meshes, ready for one or more DrawAll calls
 	// (After this is called, Draw3DShape should not be called until the InstancedMeshRenderer is clear()-ed)
@@ -955,12 +1019,13 @@ public:
 	{
 		ShadowCastingShapes = 0x1,
 		TranslucentShapes = 0x2,
-		OldShadows = 0x4
+		AdditiveShapes = 0x4,
+		OldShadows = 0x8
 	};
-	static constexpr int DrawParts_All = DrawParts::ShadowCastingShapes | DrawParts::TranslucentShapes;
+	static constexpr int DrawParts_All = DrawParts::ShadowCastingShapes | DrawParts::TranslucentShapes | DrawParts::AdditiveShapes;
 
 	// Draws all queued meshes, given a projection + view matrix
-	bool DrawAll(uint64_t currentGameFrame, const glm::mat4 &projectionMatrix, const glm::mat4 &viewMatrix, const ShadowCascadesInfo& shadowMVPMatrix, int drawParts = DrawParts_All, bool depthPass = false);
+	bool DrawAll(uint64_t currentGameFrame, const glm::mat4 &projectionMatrix, const glm::mat4 &viewMatrix, const Vector3f &cameraPos, const ShadowCascadesInfo& shadowMVPMatrix, int drawParts = DrawParts_All, bool depthPass = false);
 public:
 	// New, instanced rendering
 	void Draw3DShapes_Instanced(uint64_t currentGameFrame, ShaderOnce& globalsOnce, const gfx_api::Draw3DShapeInstancedGlobalUniforms& globalUniforms, int drawParts = DrawParts_All, bool depthPass = false);
@@ -978,14 +1043,28 @@ public:
 private:
 	bool useInstancedRendering = false;
 
+	static inline constexpr MemoryPoolOptions memPoolOpts {
+		32, // minimal_supported_block_size
+		65536, // largest_required_block_size
+		512, // required_capacity_for_smallest_sub_pool
+		8 // minimal_required_capacity
+	};
+
+	MemoryPool memoryPool{ memPoolOpts };
+	PoolAllocator<SHAPE> poolAllocator;
+
+	using ShapeVector = std::vector<SHAPE, PoolAllocator<SHAPE>>;
 	typedef templatedState MeshInstanceKey;
-	std::unordered_map<MeshInstanceKey, std::vector<SHAPE>> instanceMeshes;
-	std::unordered_map<MeshInstanceKey, std::vector<SHAPE>> instanceTranslucentMeshes;
+	std::unordered_map<MeshInstanceKey, ShapeVector, std::hash<MeshInstanceKey>, std::equal_to<MeshInstanceKey>, PoolAllocator<std::pair<const MeshInstanceKey, ShapeVector>>> instanceMeshes;
+	InsertionOrderMap<MeshInstanceKey, ShapeVector> instanceTranslucentMeshes;
+	InsertionOrderMap<MeshInstanceKey, ShapeVector> instanceTranslucentMeshesNoDepthWrite;
+	InsertionOrderMap<MeshInstanceKey, ShapeVector> instanceAdditiveMeshes;
 	size_t instancesCount = 0;
 	size_t translucentInstancesCount = 0;
+	size_t additiveInstancesCount = 0;
 
-	std::vector<SHAPE> tshapes;
-	std::vector<SHAPE> shapes;
+	ShapeVector tshapes;
+	ShapeVector shapes;
 
 	std::vector<gfx_api::Draw3DShapePerInstanceInterleavedData> instancesData;
 	std::vector<gfx_api::buffer*> instanceDataBuffers;
@@ -1009,8 +1088,21 @@ private:
 	};
 	std::vector<InstancedDrawCall> finalizedDrawCalls;
 	size_t startIdxTranslucentDrawCalls = 0;
+	size_t startIdxTranslucentNoDepthWriteDrawCalls = 0;
+	size_t startIdxAdditiveDrawCalls = 0;
 };
 
+InstancedMeshRenderer::InstancedMeshRenderer()
+	: poolAllocator(memoryPool),
+	instanceMeshes(poolAllocator),
+	instanceTranslucentMeshes(poolAllocator),
+	instanceTranslucentMeshesNoDepthWrite(poolAllocator),
+	instanceAdditiveMeshes(poolAllocator),
+	tshapes(poolAllocator),
+	shapes(poolAllocator)
+{
+}
+
 bool InstancedMeshRenderer::initialize()
 {
 	reset();
@@ -1034,8 +1126,11 @@ void InstancedMeshRenderer::clear()
 {
 	instanceMeshes.clear();
 	instanceTranslucentMeshes.clear();
+	instanceTranslucentMeshesNoDepthWrite.clear();
+	instanceAdditiveMeshes.clear();
 	instancesCount = 0;
 	translucentInstancesCount = 0;
+	additiveInstancesCount = 0;
 	tshapes.clear();
 	shapes.clear();
 	lightmapTexture = nullptr;
@@ -1052,7 +1147,7 @@ void InstancedMeshRenderer::reset()
 	instanceDataBuffers.clear();
 }
 
-bool InstancedMeshRenderer::Draw3DShape(iIMDShape *shape, int frame, PIELIGHT teamcolour, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth)
+bool InstancedMeshRenderer::Draw3DShape(const iIMDShape *shape, int frame, PIELIGHT teamcolour, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth)
 {
 	bool light = true;
 
@@ -1093,6 +1188,11 @@ bool InstancedMeshRenderer::Draw3DShape(iIMDShape *shape, int frame, PIELIGHT te
 	tshape.stretch = stretchDepth;
 	tshape.modelMatrix = modelMatrix;
 
+	if (pieFlag & pie_SHIELD)
+	{
+		tshape.modelMatrix = glm::scale(tshape.modelMatrix, glm::vec3(pie_SHIELD_FACTOR, pie_SHIELD_FACTOR, pie_SHIELD_FACTOR));
+	}
+
 	if (pieFlag & pie_HEIGHT_SCALED)	// construct
 	{
 		tshape.modelMatrix = glm::scale(tshape.modelMatrix, glm::vec3(1.0f, (float)pieFlagData / (float)pie_RAISE_SCALE, 1.0f));
@@ -1102,11 +1202,30 @@ bool InstancedMeshRenderer::Draw3DShape(iIMDShape *shape, int frame, PIELIGHT te
 		tshape.modelMatrix = glm::translate(tshape.modelMatrix, glm::vec3(1.0f, (-shape->max.y * (pie_RAISE_SCALE - pieFlagData)) * (1.0f / pie_RAISE_SCALE), 1.0f));
 	}
 
-	if (pieFlag & (pie_ADDITIVE | pie_TRANSLUCENT | pie_PREMULTIPLIED))
+	if (pieFlag & (pie_ADDITIVE | pie_PREMULTIPLIED))
 	{
 		if (useInstancedRendering)
 		{
-			instanceTranslucentMeshes[currentState].push_back(tshape);
+			instanceAdditiveMeshes[currentState].push_back(tshape);
+		}
+		else
+		{
+			tshapes.push_back(tshape);
+		}
+		++additiveInstancesCount;
+	}
+	else if (pieFlag & pie_TRANSLUCENT)
+	{
+		if (useInstancedRendering)
+		{
+			if (pieFlag & pie_NODEPTHWRITE)
+			{
+				instanceTranslucentMeshesNoDepthWrite[currentState].push_back(tshape);
+			}
+			else
+			{
+				instanceTranslucentMeshes[currentState].push_back(tshape);
+			}
 		}
 		else
 		{
@@ -1144,7 +1263,8 @@ bool InstancedMeshRenderer::Draw3DShape(iIMDShape *shape, int frame, PIELIGHT te
 		}
 		if (useInstancedRendering)
 		{
-			instanceMeshes[currentState].push_back(tshape);
+			auto [it, _] = instanceMeshes.try_emplace(currentState, poolAllocator);
+			it->second.push_back(tshape);
 		}
 		else
 		{
@@ -1175,7 +1295,7 @@ void pie_CleanUp()
 	}
 }
 
-bool pie_Draw3DShape(iIMDShape *shape, int frame, int team, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth, bool onlySingleLevel)
+bool pie_Draw3DShape(const iIMDShape *shape, int frame, int team, PIELIGHT colour, int pieFlag, int pieFlagData, const glm::mat4 &modelMatrix, const glm::mat4 &viewMatrix, float stretchDepth, bool onlySingleLevel)
 {
 	pieCount++;
 
@@ -1184,9 +1304,9 @@ bool pie_Draw3DShape(iIMDShape *shape, int frame, int team, PIELIGHT colour, int
 
 	bool retVal = false;
 	const bool drawAllLevels = (shape->modelLevel == 0) && !onlySingleLevel;
-	const PIELIGHT teamcolour = pal_GetTeamColour(team);
+	const PIELIGHT teamcolour = shape->getTeamColourForModel(team);
 
-	iIMDShape *pCurrShape = shape;
+	const iIMDShape *pCurrShape = shape;
 	do
 	{
 		if (pieFlag & pie_BUTTON)
@@ -1212,7 +1332,7 @@ static void pie_ShadowDrawLoop(ShadowCache &shadowCache, const glm::mat4& projec
 //	size_t uncachedShadowDraws = 0;
 	for (unsigned i = 0; i < scshapes.size(); i++)
 	{
-		/*DrawShadowResult result =*/ pie_DrawShadow(shadowCache, scshapes[i].shape, scshapes[i].flag, scshapes[i].flag_data, scshapes[i].light, scshapes[i].modelViewMatrix);
+		/*DrawShadowResult result =*/ pie_DrawShadow(shadowCache, const_cast<iIMDShape*>(scshapes[i].shape), scshapes[i].flag, scshapes[i].flag_data, scshapes[i].light, scshapes[i].modelViewMatrix);
 //		if (result == DRAW_SUCCESS_CACHED)
 //		{
 //			++cachedShadowDraws;
@@ -1292,7 +1412,7 @@ void pie_FinalizeMeshes(uint64_t currentGameFrame)
 	instancedMeshRenderer.FinalizeInstances();
 }
 
-void pie_DrawAllMeshes(uint64_t currentGameFrame, const glm::mat4 &projectionMatrix, const glm::mat4& viewMatrix, const ShadowCascadesInfo& shadowMVPMatrix, bool depthPass)
+void pie_DrawAllMeshes(uint64_t currentGameFrame, const glm::mat4 &projectionMatrix, const glm::mat4& viewMatrix, const Vector3f &cameraPos, const ShadowCascadesInfo& shadowMVPMatrix, bool depthPass)
 {
 	int drawParts = InstancedMeshRenderer::DrawParts_All;
 	if (shadowMode == ShadowMode::Fallback_Stencil_Shadows)
@@ -1312,7 +1432,7 @@ void pie_DrawAllMeshes(uint64_t currentGameFrame, const glm::mat4 &projectionMat
 	{
 		return;
 	}
-	instancedMeshRenderer.DrawAll(currentGameFrame, projectionMatrix, viewMatrix, shadowMVPMatrix, drawParts, depthPass);
+	instancedMeshRenderer.DrawAll(currentGameFrame, projectionMatrix, viewMatrix, cameraPos, shadowMVPMatrix, drawParts, depthPass);
 }
 
 bool InstancedMeshRenderer::FinalizeInstances()
@@ -1326,12 +1446,12 @@ bool InstancedMeshRenderer::FinalizeInstances()
 	instancesData.clear();
 	finalizedDrawCalls.clear();
 
-	if (instancesCount + translucentInstancesCount == 0)
+	if (instancesCount + translucentInstancesCount + additiveInstancesCount == 0)
 	{
 		return true;
 	}
 
-	instancesData.reserve(instancesCount + translucentInstancesCount);
+	instancesData.reserve(instancesCount + translucentInstancesCount + additiveInstancesCount);
 
 	for (const auto& mesh : instanceMeshes)
 	{
@@ -1357,6 +1477,32 @@ bool InstancedMeshRenderer::FinalizeInstances()
 		finalizedDrawCalls.emplace_back(mesh.first, meshInstances.size(), startingIdxInInstancesBuffer);
 	}
 
+	startIdxTranslucentNoDepthWriteDrawCalls = finalizedDrawCalls.size();
+
+	for (const auto& mesh : instanceTranslucentMeshesNoDepthWrite)
+	{
+		const auto& meshInstances = mesh.second;
+		size_t startingIdxInInstancesBuffer = instancesData.size();
+		for (const auto& instance : meshInstances)
+		{
+			instancesData.push_back(GenerateInstanceData(instance.frame, instance.colour, instance.teamcolour, instance.flag, instance.flag_data, instance.modelMatrix, instance.stretch));
+		}
+		finalizedDrawCalls.emplace_back(mesh.first, meshInstances.size(), startingIdxInInstancesBuffer);
+	}
+
+	startIdxAdditiveDrawCalls = finalizedDrawCalls.size();
+
+	for (const auto& mesh : instanceAdditiveMeshes)
+	{
+		const auto& meshInstances = mesh.second;
+		size_t startingIdxInInstancesBuffer = instancesData.size();
+		for (const auto& instance : meshInstances)
+		{
+			instancesData.push_back(GenerateInstanceData(instance.frame, instance.colour, instance.teamcolour, instance.flag, instance.flag_data, instance.modelMatrix, instance.stretch));
+		}
+		finalizedDrawCalls.emplace_back(mesh.first, meshInstances.size(), startingIdxInInstancesBuffer);
+	}
+
 	// Upload buffer
 	++currInstanceBufferIdx;
 	if (currInstanceBufferIdx >= instanceDataBuffers.size())
@@ -1370,7 +1516,7 @@ bool InstancedMeshRenderer::FinalizeInstances()
 	return true;
 }
 
-bool InstancedMeshRenderer::DrawAll(uint64_t currentGameFrame, const glm::mat4& projectionMatrix, const glm::mat4& viewMatrix, const ShadowCascadesInfo& shadowCascades, int drawParts, bool depthPass)
+bool InstancedMeshRenderer::DrawAll(uint64_t currentGameFrame, const glm::mat4& projectionMatrix, const glm::mat4& viewMatrix, const Vector3f &cameraPos, const ShadowCascadesInfo& shadowCascades, int drawParts, bool depthPass)
 {
 	perFrameUniformsShaderOnce.reset();
 
@@ -1381,21 +1527,20 @@ bool InstancedMeshRenderer::DrawAll(uint64_t currentGameFrame, const glm::mat4&
 	glm::vec4 specular(lighting0[LIGHT_SPECULAR][0], lighting0[LIGHT_SPECULAR][1], lighting0[LIGHT_SPECULAR][2], lighting0[LIGHT_SPECULAR][3]);
 
 	const auto &renderState = getCurrentRenderState();
-	const glm::vec4 fogColor = renderState.fogEnabled ? glm::vec4(
-		renderState.fogColour.vector[0] / 255.f,
-		renderState.fogColour.vector[1] / 255.f,
-		renderState.fogColour.vector[2] / 255.f,
-		renderState.fogColour.vector[3] / 255.f
-	) : glm::vec4(0.f);
+	const glm::vec4 fogColor = renderState.fogEnabled ? pielightToRGBAVec4(renderState.fogColour) : glm::vec4(0.f);
 
 
 	if (useInstancedRendering)
 	{
+
+		auto bucketLight = getCurrentLightingManager().getPointLightBuckets();
+		auto dimension = gfx_api::context::get().getDrawableDimensions();
 		gfx_api::Draw3DShapeInstancedGlobalUniforms globalUniforms {
 			projectionMatrix, viewMatrix, modelUVLightmapMatrix, {shadowCascades.shadowMVPMatrix[0], shadowCascades.shadowMVPMatrix[1], shadowCascades.shadowMVPMatrix[2]},
-			glm::vec4(currentSunPosition, 0.f), sceneColor, ambient, diffuse, specular, fogColor,
+			glm::vec4(cameraPos, 0.f), glm::vec4(currentSunPosition, 0.f),
+			sceneColor, ambient, diffuse, specular, fogColor,
 			{shadowCascades.shadowCascadeSplit[0], shadowCascades.shadowCascadeSplit[1], shadowCascades.shadowCascadeSplit[2], pie_getPerspectiveZFar()}, shadowCascades.shadowMapSize,
-			renderState.fogBegin, renderState.fogEnd, pie_GetShaderTime(), renderState.fogEnabled
+			renderState.fogBegin, renderState.fogEnd, pie_GetShaderTime(), renderState.fogEnabled, static_cast<int>(dimension.first), static_cast<int>(dimension.second), 0.f, bucketLight.positions, bucketLight.colorAndEnergy, bucketLight.bucketOffsetAndSize, bucketLight.light_index, static_cast<int>(bucketLight.bucketDimensionUsed)
 		};
 		Draw3DShapes_Instanced(currentGameFrame, perFrameUniformsShaderOnce, globalUniforms, drawParts, depthPass);
 	}
@@ -1413,7 +1558,7 @@ bool InstancedMeshRenderer::DrawAll(uint64_t currentGameFrame, const glm::mat4&
 }
 
 template<SHADER_MODE shader, typename Draw3DInstancedPSO>
-static void drawInstanced3dShapeTemplated_Inner(ShaderOnce& globalsOnce, const gfx_api::Draw3DShapeInstancedGlobalUniforms& globalUniforms, const iIMDShape * shape, gfx_api::buffer* instanceDataBuffer, size_t instanceBufferOffset, size_t instance_count, gfx_api::texture* lightmapTexture)
+static void drawInstanced3dShapeTemplated_Inner(ShaderOnce& globalsOnce, const gfx_api::Draw3DShapeInstancedGlobalUniforms& globalUniforms, const iIMDShape * shape, gfx_api::buffer* instanceDataBuffer, size_t instanceBufferOffset, size_t instance_count, gfx_api::texture* lightmapTexture, bool shieldEffect)
 {
 	const auto& textures = shape->getTextures();
 	auto* tcmask = textures.tcmaskpage != iV_TEX_INVALID ? &pie_Texture(textures.tcmaskpage) : nullptr;
@@ -1421,7 +1566,7 @@ static void drawInstanced3dShapeTemplated_Inner(ShaderOnce& globalsOnce, const g
 	auto* specularmap = textures.specularpage != iV_TEX_INVALID ? &pie_Texture(textures.specularpage) : nullptr;
 
 	gfx_api::Draw3DShapeInstancedPerMeshUniforms meshUniforms {
-		tcmask ? 1 : 0, normalmap != nullptr, specularmap != nullptr, shape->buffers[VBO_TANGENT] != nullptr
+		tcmask ? 1 : 0, normalmap != nullptr, specularmap != nullptr, shape->buffers[VBO_TANGENT] != nullptr, shieldEffect ? 1 : 0
 	};
 
 	gfx_api::buffer* pTangentBuffer = (shape->buffers[VBO_TANGENT] != nullptr) ? shape->buffers[VBO_TANGENT] : getZeroedVertexBuffer(shape->vertexCount * 4 * sizeof(gfx_api::gfxFloat));
@@ -1472,39 +1617,48 @@ static void drawInstanced3dShapeDepthOnly(ShaderOnce& globalsOnce, const gfx_api
 //	Draw3DInstancedPSO::get().unbind_vertex_buffers(shape->buffers[VBO_VERTEX], shape->buffers[VBO_NORMAL], shape->buffers[VBO_TEXCOORD]);
 }
 
-template<SHADER_MODE shader, typename AdditivePSO, typename AdditiveNoDepthWRTPSO, typename AlphaPSO, typename AlphaNoDepthWRTPSO, typename PremultipliedPSO, typename OpaquePSO>
+template<SHADER_MODE shader, typename AdditivePSO, typename AdditiveNoDepthWRTPSO, typename AlphaPSO, typename AlphaNoDepthWRTPSO, typename PremultipliedPSO, typename PremultipliedNoDepthWRTPSO, typename OpaquePSO>
 static void drawInstanced3dShapeTemplated(ShaderOnce& globalsOnce, const gfx_api::Draw3DShapeInstancedGlobalUniforms& globalUniforms, const iIMDShape * shape, int pieFlag, gfx_api::buffer* instanceDataBuffer, size_t instanceBufferOffset, size_t instance_count, gfx_api::texture* lightmapTexture)
 {
+	bool shieldEffect = pieFlag & pie_SHIELD;
+
 	/* Set tranlucency */
 	if (pieFlag & pie_ADDITIVE)
 	{
 		if (!(pieFlag & pie_NODEPTHWRITE))
 		{
-			return drawInstanced3dShapeTemplated_Inner<shader, AdditivePSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+			return drawInstanced3dShapeTemplated_Inner<shader, AdditivePSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
 		}
 		else
 		{
-			return drawInstanced3dShapeTemplated_Inner<shader, AdditiveNoDepthWRTPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+			return drawInstanced3dShapeTemplated_Inner<shader, AdditiveNoDepthWRTPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
 		}
 	}
 	else if (pieFlag & pie_TRANSLUCENT)
 	{
 		if (!(pieFlag & pie_NODEPTHWRITE))
 		{
-			return drawInstanced3dShapeTemplated_Inner<shader, AlphaPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+			return drawInstanced3dShapeTemplated_Inner<shader, AlphaPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
 		}
 		else
 		{
-			return drawInstanced3dShapeTemplated_Inner<shader, AlphaNoDepthWRTPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+			return drawInstanced3dShapeTemplated_Inner<shader, AlphaNoDepthWRTPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
 		}
 	}
 	else if (pieFlag & pie_PREMULTIPLIED)
 	{
-		return drawInstanced3dShapeTemplated_Inner<shader, PremultipliedPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+		if (!(pieFlag & pie_NODEPTHWRITE))
+		{
+			return drawInstanced3dShapeTemplated_Inner<shader, PremultipliedPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
+		}
+		else
+		{
+			return drawInstanced3dShapeTemplated_Inner<shader, PremultipliedNoDepthWRTPSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
+		}
 	}
 	else
 	{
-		return drawInstanced3dShapeTemplated_Inner<shader, OpaquePSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+		return drawInstanced3dShapeTemplated_Inner<shader, OpaquePSO>(globalsOnce, globalUniforms, shape, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture, shieldEffect);
 	}
 }
 
@@ -1556,11 +1710,11 @@ static void pie_Draw3DShape2_Instanced(ShaderOnce& globalsOnce, const gfx_api::D
 	}
 	else if (light)
 	{
-		drawInstanced3dShapeTemplated<SHADER_COMPONENT_INSTANCED, gfx_api::Draw3DShapeAdditive_Instanced, gfx_api::Draw3DShapeAdditiveNoDepthWRT_Instanced, gfx_api::Draw3DShapeAlpha_Instanced, gfx_api::Draw3DShapeAlphaNoDepthWRT_Instanced, gfx_api::Draw3DShapePremul_Instanced, gfx_api::Draw3DShapeOpaque_Instanced>(globalsOnce, globalUniforms, shape, pieFlag, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+		drawInstanced3dShapeTemplated<SHADER_COMPONENT_INSTANCED, gfx_api::Draw3DShapeAdditive_Instanced, gfx_api::Draw3DShapeAdditiveNoDepthWRT_Instanced, gfx_api::Draw3DShapeAlpha_Instanced, gfx_api::Draw3DShapeAlphaNoDepthWRT_Instanced, gfx_api::Draw3DShapePremul_Instanced, gfx_api::Draw3DShapePremulNoDepthWRT_Instanced, gfx_api::Draw3DShapeOpaque_Instanced>(globalsOnce, globalUniforms, shape, pieFlag, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
 	}
 	else
 	{
-		drawInstanced3dShapeTemplated<SHADER_NOLIGHT_INSTANCED, gfx_api::Draw3DShapeNoLightAdditive_Instanced, gfx_api::Draw3DShapeNoLightAdditiveNoDepthWRT_Instanced, gfx_api::Draw3DShapeNoLightAlpha_Instanced, gfx_api::Draw3DShapeNoLightAlphaNoDepthWRT_Instanced, gfx_api::Draw3DShapeNoLightPremul_Instanced, gfx_api::Draw3DShapeNoLightOpaque_Instanced>(globalsOnce, globalUniforms, shape, pieFlag, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
+		drawInstanced3dShapeTemplated<SHADER_NOLIGHT_INSTANCED, gfx_api::Draw3DShapeNoLightAdditive_Instanced, gfx_api::Draw3DShapeNoLightAdditiveNoDepthWRT_Instanced, gfx_api::Draw3DShapeNoLightAlpha_Instanced, gfx_api::Draw3DShapeNoLightAlphaNoDepthWRT_Instanced, gfx_api::Draw3DShapeNoLightPremul_Instanced, gfx_api::Draw3DShapeNoLightPremulNoDepthWRT_Instanced, gfx_api::Draw3DShapeNoLightOpaque_Instanced>(globalsOnce, globalUniforms, shape, pieFlag, instanceDataBuffer, instanceBufferOffset, instance_count, lightmapTexture);
 	}
 
 	polyCount += shape->polys.size();
@@ -1608,16 +1762,49 @@ void InstancedMeshRenderer::Draw3DShapes_Instanced(uint64_t currentGameFrame, Sh
 
 	if ((drawParts & DrawParts::TranslucentShapes) == DrawParts::TranslucentShapes)
 	{
-		// Draw translucent models last
+		// Draw translucent models next
 		gfx_api::context::get().debugStringMarker("Remaining passes - translucent models");
-		for (size_t i = startIdxTranslucentDrawCalls; i < finalizedDrawCalls.size(); ++i)
+		for (size_t i = startIdxTranslucentDrawCalls; i < startIdxTranslucentNoDepthWriteDrawCalls; ++i)
 		{
 			const auto& call = finalizedDrawCalls[i];
 			const iIMDShape * shape = call.state.shape;
 			size_t instanceBufferOffset = static_cast<size_t>(sizeof(gfx_api::Draw3DShapePerInstanceInterleavedData) * call.startingIdxInInstancesBuffer);
 			pie_Draw3DShape2_Instanced(perFrameUniformsShaderOnce, globalUniforms, shape, call.state.pieFlag, instanceDataBuffers[currInstanceBufferIdx], instanceBufferOffset, call.instance_count, depthPass, lightmapTexture);
 		}
-		if (startIdxTranslucentDrawCalls < finalizedDrawCalls.size())
+		if (startIdxTranslucentDrawCalls < startIdxTranslucentNoDepthWriteDrawCalls)
+		{
+			// unbind last index buffer bound inside pie_Draw3DShape2
+			gfx_api::context::get().unbind_index_buffer(*((finalizedDrawCalls[startIdxTranslucentNoDepthWriteDrawCalls-1].state.shape)->buffers[VBO_INDEX]));
+		}
+
+		// Draw translucent (no depth write) models after
+		gfx_api::context::get().debugStringMarker("Remaining passes - translucent (no depth write) models");
+		for (size_t i = startIdxTranslucentNoDepthWriteDrawCalls; i < startIdxAdditiveDrawCalls; ++i)
+		{
+			const auto& call = finalizedDrawCalls[i];
+			const iIMDShape * shape = call.state.shape;
+			size_t instanceBufferOffset = static_cast<size_t>(sizeof(gfx_api::Draw3DShapePerInstanceInterleavedData) * call.startingIdxInInstancesBuffer);
+			pie_Draw3DShape2_Instanced(perFrameUniformsShaderOnce, globalUniforms, shape, call.state.pieFlag, instanceDataBuffers[currInstanceBufferIdx], instanceBufferOffset, call.instance_count, depthPass, lightmapTexture);
+		}
+		if (startIdxTranslucentNoDepthWriteDrawCalls < startIdxAdditiveDrawCalls)
+		{
+			// unbind last index buffer bound inside pie_Draw3DShape2
+			gfx_api::context::get().unbind_index_buffer(*((finalizedDrawCalls[startIdxAdditiveDrawCalls-1].state.shape)->buffers[VBO_INDEX]));
+		}
+	}
+
+	if ((drawParts & DrawParts::AdditiveShapes) == DrawParts::AdditiveShapes)
+	{
+		// Draw additive models last
+		gfx_api::context::get().debugStringMarker("Remaining passes - additive models");
+		for (size_t i = startIdxAdditiveDrawCalls; i < finalizedDrawCalls.size(); ++i)
+		{
+			const auto& call = finalizedDrawCalls[i];
+			const iIMDShape * shape = call.state.shape;
+			size_t instanceBufferOffset = static_cast<size_t>(sizeof(gfx_api::Draw3DShapePerInstanceInterleavedData) * call.startingIdxInInstancesBuffer);
+			pie_Draw3DShape2_Instanced(perFrameUniformsShaderOnce, globalUniforms, shape, call.state.pieFlag, instanceDataBuffers[currInstanceBufferIdx], instanceBufferOffset, call.instance_count, depthPass, lightmapTexture);
+		}
+		if (startIdxAdditiveDrawCalls < finalizedDrawCalls.size())
 		{
 			// unbind last index buffer bound inside pie_Draw3DShape2
 			gfx_api::context::get().unbind_index_buffer(*((finalizedDrawCalls.back().state.shape)->buffers[VBO_INDEX]));
