@@ -106,10 +106,8 @@ enum SHADER_MODE
 	SHADER_COMPONENT_DEPTH_INSTANCED,
 	SHADER_NOLIGHT,
 	SHADER_NOLIGHT_INSTANCED,
-	SHADER_TERRAIN,
 	SHADER_TERRAIN_DEPTH,
 	SHADER_TERRAIN_DEPTHMAP,
-	SHADER_DECALS,
 	SHADER_WATER,
 	SHADER_RECT,
 	SHADER_RECT_INSTANCED,
