@@ -38,6 +38,7 @@
 
 TableRow::TableRow()
 : W_BUTTON()
+, highlightColor(WZCOL_TRANSPARENT_BOX)
 , disabledColor(WZCOL_FORM_DISABLE)
 {
 	AudioCallback = nullptr;
@@ -90,15 +91,26 @@ void TableRow::setHighlightsOnMouseOver(bool value)
 	highlightsOnMouseOver = value;
 }
 
+void TableRow::setHighlightColor(PIELIGHT newHighlightColor)
+{
+	highlightColor = newHighlightColor;
+}
+
 void TableRow::setDrawBorder(optional<PIELIGHT> newBorderColor)
 {
 	borderColor = newBorderColor;
 }
 
+void TableRow::setBackgroundColor(optional<PIELIGHT> newBackgroundColor)
+{
+	backgroundColor = newBackgroundColor;
+}
+
 // Set whether row is "disabled"
 void TableRow::setDisabled(bool disabled)
 {
 	disabledRow = disabled;
+	W_BUTTON::setState((disabled) ? WBUT_DISABLE : 0);
 }
 
 // Set row disable overlay color
@@ -124,13 +136,19 @@ void TableRow::display(int xOffset, int yOffset)
 	int x1 = x0 + width();
 	int y1 = y0 + height();
 
+	if (highlightsOnMouseOver && isMouseOverRowOrChildren() && !disabledRow)
+	{
+		pie_UniTransBoxFill(x0, y0, x1, y1, highlightColor);
+	}
+	else if (backgroundColor.has_value())
+	{
+		pie_UniTransBoxFill(x0, y0, x1, y1, backgroundColor.value());
+	}
+
 	if (borderColor.has_value())
 	{
 		iV_Box(x0, y0, x1, y1, borderColor.value());
 	}
-
-	if (!highlightsOnMouseOver || !isMouseOverRowOrChildren() || disabledRow) { return; }
-	iV_TransBoxFill(x0, y0, x1, y1);
 }
 
 void TableRow::displayRecursive(WidgetGraphicsContext const& context)
@@ -156,19 +174,24 @@ void TableRow::displayRecursive(WidgetGraphicsContext const& context)
 	pie_UniTransBoxFill(x0, y0, x0 + width(), y0 + height(), disabledColor);
 }
 
-bool TableRow::hitTest(int x, int y)
+bool TableRow::hitTest(int x, int y) const
 {
-	if (disabledRow) { return false; }
+	if (x >= maxDisplayedColumnX1) { return false; }
 	return W_BUTTON::hitTest(x, y);
 }
 
-bool TableRow::processClickRecursive(W_CONTEXT *psContext, WIDGET_KEY key, bool wasPressed)
+std::shared_ptr<WIDGET> TableRow::findMouseTargetRecursive(W_CONTEXT *psContext, WIDGET_KEY key, bool wasPressed)
 {
-	// if processClickRecursive was called for this row, it means the mouse is over it
-	// (see WIDGET::processClickRecursive)
+	// if findMouseTargetRecursive was called for this row, it means the mouse is over it
+	// (see WIDGET::findMouseTargetRecursive)
 	lastFrameMouseIsOverRowOrChildren = frameGetFrameNumber();
 
-	return WIDGET::processClickRecursive(psContext, key, wasPressed);
+
+	if (disabledRow)
+	{
+		return shared_from_this();
+	}
+	return WIDGET::findMouseTargetRecursive(psContext, key, wasPressed);
 }
 
 bool TableRow::isMouseOverRowOrChildren() const
@@ -191,6 +214,7 @@ void TableRow::resizeColumns(const std::vector<size_t>& newColumnWidths, int col
 		columnWidgets[colIdx]->show();
 		lastColumnEndX = (columnWidgets[colIdx]->x() + columnWidgets[colIdx]->width());
 	}
+	maxDisplayedColumnX1 = lastColumnEndX;
 	// hide any additional column widgets
 	for (; colIdx < columnWidgets.size(); colIdx++)
 	{
@@ -218,6 +242,8 @@ protected:
 	virtual void released(W_CONTEXT *, WIDGET_KEY) override;
 	virtual void run(W_CONTEXT *psContext) override;
 	virtual void geometryChanged() override;
+	virtual bool capturesMouseDrag(WIDGET_KEY) override;
+	virtual void mouseDragged(WIDGET_KEY, W_CONTEXT *start, W_CONTEXT *current) override;
 
 public:
 	void addColumn(const TableColumn& column);
@@ -278,17 +304,29 @@ void TableHeader::display(int xOffset, int yOffset)
 	}
 }
 
-void TableHeader::clicked(W_CONTEXT *psContext, WIDGET_KEY key)
+bool TableHeader::capturesMouseDrag(WIDGET_KEY)
 {
-	if (userResizableHeaders && key == WKEY_PRIMARY && !columns.empty())
+	return userResizableHeaders;
+}
+
+void TableHeader::mouseDragged(WIDGET_KEY key, W_CONTEXT *start, W_CONTEXT *current)
+{
+	if (!userResizableHeaders || key != WKEY_PRIMARY || columns.empty())
 	{
+		return;
+	}
+
+	if (!dragStart.has_value())
+	{
+		dragStart = Vector2i(start->mx, start->my);
+
 		// determine the column that is being resized
 		colBeingResized = nullopt;
 		for (size_t colIdx = columns.size() - 1; /* termination handled in loop body */; colIdx--)
 		{
 			auto& columnWidget = columns[colIdx].columnWidget;
 			int col_x1 = columnWidget->x() + columnWidget->width();
-			if (psContext->mx > col_x1)
+			if (start->mx > col_x1)
 			{
 				if (columns[colIdx].resizeBehavior != TableColumn::ResizeBehavior::FIXED_WIDTH)
 				{
@@ -302,13 +340,36 @@ void TableHeader::clicked(W_CONTEXT *psContext, WIDGET_KEY key)
 			}
 		}
 		if (!colBeingResized.has_value()) { return; }
-		dragStart = Vector2i(psContext->mx, psContext->my);
 	}
+
+	if (dragStart.has_value() && colBeingResized.has_value())
+	{
+		// handle column resize while dragging
+		Vector2i currentMousePos(current->mx, current->my);
+		Vector2i dragDelta(currentMousePos.x - dragStart.value().x, currentMousePos.y - dragStart.value().y);
+
+		int priorColumnWidth = columns[colBeingResized.value()].columnWidget->width();
+		size_t newProposedColumnWidth = static_cast<size_t>(std::max<int>(priorColumnWidth + dragDelta.x, 0));
+		if (auto table = parentTable.lock())
+		{
+			auto result = table->header_changeColumnWidth(colBeingResized.value(), static_cast<size_t>(newProposedColumnWidth));
+			if (result.has_value())
+			{
+				Vector2i currentDragLogicalPos = dragStart.value();
+				currentDragLogicalPos.x += (static_cast<int>(result.value()) - priorColumnWidth);
+				dragStart = currentDragLogicalPos;
+			}
+		}
+	}
+}
+
+void TableHeader::clicked(W_CONTEXT *psContext, WIDGET_KEY key)
+{
+	// currently, no-op
 }
 
 void TableHeader::released(W_CONTEXT *, WIDGET_KEY)
 {
-	if (!userResizableHeaders || !dragStart.has_value()) { return; }
 	colBeingResized = nullopt;
 	dragStart = nullopt;
 }
@@ -339,32 +400,7 @@ void TableHeader::setColumnPadding(Vector2i padding)
 
 void TableHeader::run(W_CONTEXT *psContext)
 {
-	if (!userResizableHeaders || !dragStart.has_value()) { return; }
-
-	/* If the mouse is released *anywhere*, stop dragging */
-	if (mouseReleased(MOUSE_LMB))
-	{
-		colBeingResized = nullopt;
-		dragStart = nullopt;
-		return;
-	}
-
-	Vector2i currentMousePos(psContext->mx, psContext->my);
-	if (currentMousePos == dragStart.value()) { return; }
-	Vector2i dragDelta(currentMousePos.x - dragStart.value().x, currentMousePos.y - dragStart.value().y);
-
-	int priorColumnWidth = columns[colBeingResized.value()].columnWidget->width();
-	size_t newProposedColumnWidth = static_cast<size_t>(std::max<int>(priorColumnWidth + dragDelta.x, 0));
-	if (auto table = parentTable.lock())
-	{
-		auto result = table->header_changeColumnWidth(colBeingResized.value(), static_cast<size_t>(newProposedColumnWidth));
-		if (result.has_value())
-		{
-			Vector2i currentDragLogicalPos = dragStart.value();
-			currentDragLogicalPos.x += (static_cast<int>(result.value()) - priorColumnWidth);
-			dragStart = currentDragLogicalPos;
-		}
-	}
+	// currently, no-op
 }
 
 void TableHeader::geometryChanged()
@@ -445,7 +481,11 @@ std::shared_ptr<ScrollableTableWidget> ScrollableTableWidget::make(const std::ve
 	result->scrollableList->setCalcLayout(LAMBDA_CALCLAYOUT_SIMPLE({
 		if (auto psParent = std::dynamic_pointer_cast<ScrollableTableWidget>(psWidget->parent()))
 		{
-			int y0 = psParent->header->y() + psParent->header->height() + psParent->scrollableList->getItemSpacing();
+			int y0 = 0;
+			if (psParent->header->visible())
+			{
+				y0 = psParent->header->y() + psParent->header->height() + psParent->scrollableList->getItemSpacing();
+			}
 			psWidget->setGeometry(0, y0, psParent->width(), psParent->height() - y0);
 		}
 	}));
@@ -497,6 +537,16 @@ void ScrollableTableWidget::clearRows()
 	rows.clear();
 }
 
+void ScrollableTableWidget::setHeaderVisible(bool visible)
+{
+	if (visible == header->visible())
+	{
+		return;
+	}
+	header->show(visible);
+	geometryChanged();
+}
+
 void ScrollableTableWidget::setRowDisabled(size_t row, bool disabled)
 {
 	ASSERT_OR_RETURN(, row < rows.size(), "Invalid row idx: %zu", row);
