@@ -26,6 +26,7 @@
 #include "lib/framework/frame.h"
 
 #include "advvis.h"
+#include "profiling.h"
 #include "map.h"
 
 // ------------------------------------------------------------------------------------
@@ -40,19 +41,13 @@ static bool bRevealActive = true;
 // For display only (*NOT* for use in game state calculations)
 inline float getTileIllumination(const MAPTILE *psTile)
 {
-	switch (terrainShaderType)
-	{
-		case TerrainShaderType::SINGLE_PASS:
-			return psTile->ambientOcclusion; // sunlight is handled by shaders so only AO needed for lightmap
-		case TerrainShaderType::FALLBACK:
-			return psTile->illumination;
-	}
-	return psTile->illumination; // silence GCC warning
+	return psTile->ambientOcclusion; // sunlight is handled by shaders so only AO needed for lightmap
 }
 
 // ------------------------------------------------------------------------------------
 void	avUpdateTiles()
 {
+	WZ_PROFILE_SCOPE(avUpdateTiles);
 	const int len = mapHeight * mapWidth;
 	const int playermask = 1 << selectedPlayer;
 	UDWORD i = 0;
@@ -87,7 +82,7 @@ void	avUpdateTiles()
 }
 
 // ------------------------------------------------------------------------------------
-UDWORD	avGetObjLightLevel(BASE_OBJECT *psObj, UDWORD origLevel)
+UDWORD	avGetObjLightLevel(BASE_OBJECT const *psObj, UDWORD origLevel)
 {
 	float div = (float)psObj->visibleForLocalDisplay() / 255.f;
 	unsigned int lowest = origLevel / START_DIVIDE;
