@@ -1835,7 +1835,7 @@ INT_RETVAL intRunWidgets()
 	const DebugInputManager& dbgInputManager = gInputManager.debugManager();
 	if ((testPlayerHasLost() || testPlayerHasWon()) && !bMultiPlayer && intMode != INT_MISSIONRES && !dbgInputManager.debugMappingsAllowed())
 	{
-		debug(LOG_ERROR, "PlayerHasLost Or Won");
+		debug(LOG_INFO, "PlayerHasLost Or Won");
 		intResetScreen(true);
 		retCode = INT_QUIT;
 	}
@@ -2604,7 +2604,7 @@ static bool intAddDebugStatsForm(BASE_STATS **_ppsStatsList, UDWORD numStats)
 			bar = widgAddBarGraph(psWScreen, &sBarInit);
 			bar->setBackgroundColour(WZCOL_BLACK);
 		}
-		WzString costString = WzString::fromUtf8(astringf(_("Cost: %u"), powerCost));
+		WzString costString = WzString::format(_("Cost: %u"), powerCost);
 		tipString.append("\n");
 		tipString.append(costString);
 		button->setTip(tipString.toUtf8().c_str());
@@ -3096,7 +3096,7 @@ bool isSecondaryWindowUp()
 
 void setSecondaryWindowUp(bool value)
 {
-	secondaryWindowUp = true;
+	secondaryWindowUp = value;
 }
 
 void intSetShouldShowRedundantDesign(bool value)
