@@ -604,12 +604,12 @@ private:
 
 	std::string getTip() override
 	{
-		WzString costString = WzString::fromUtf8(astringf(_("Cost: %u"), getCost()));
+		WzString costString = WzString::format(_("Cost: %u"), getCost());
 		auto stats = getStats();
 		WzString tipString = (stats == nullptr) ? "" : getLocalizedStatsName(stats);
 		if (stats && !stats->category.isEmpty())
 		{
-			tipString.append(astringf("\n(%s %d/%d)", stats->category.toUtf8().c_str(), stats->categoryProgress, stats->categoryMax).c_str());
+			tipString.append(astringf("\n(%s %u/%u)", stats->category.toUtf8().c_str(), static_cast<unsigned>(stats->categoryProgress), static_cast<unsigned>(stats->categoryMax)).c_str());
 		}
 		tipString.append("\n");
 		tipString.append(costString);
