@@ -39,8 +39,12 @@ public:
 	/* (Re-)Initializes mappings to their default values. If `bForceDefaults` is true, any existing mappings will be overwritten with the defaults */
 	void resetMappings(const bool bForceDefaults, const KeyFunctionConfiguration& keyFuncConfig);
 
+	void saveMappings();
+
 	void processMappings(const bool bAllowMouseWheelEvents);
 
+	nonstd::optional<std::reference_wrapper<const KeyMapping>> findCurrentMapping(const bool bAllowMouseWheelEvents, bool filterHidden);
+
 	// Subsystems/General
 public:
 	KeyMappings& mappings();
@@ -50,6 +54,8 @@ public:
 
 	DebugInputManager& debugManager();
 
+	void setKeyMapJsonPath(const std::string& path);
+
 	void shutdown();
 
 	// Map markers
@@ -78,6 +84,7 @@ private:
 	KeyMappings keyMappings;
 	std::unordered_map<KEY_CODE, KeyFunctionInfo, KeyCodeHash> markerKeyFunctions;
 	bool bMappingsSortOrderDirty = true;
+	std::string currentKeyMapJsonPath;
 
 	DebugInputManager dbgInputManager = DebugInputManager(MAX_PLAYERS);
 };
