@@ -70,12 +70,12 @@ bool recvGift(NETQUEUE queue)
 	int		audioTrack;
 	uint32_t droidID;
 
-	NETbeginDecode(queue, GAME_GIFT);
-	NETuint8_t(&type);
-	NETuint8_t(&from);
-	NETuint8_t(&to);
-	NETuint32_t(&droidID);
-	NETend();
+	auto r = NETbeginDecode(queue, GAME_GIFT);
+	NETuint8_t(r, type);
+	NETuint8_t(r, from);
+	NETuint8_t(r, to);
+	NETuint32_t(r, droidID);
+	NETend(r);
 
 	if (!canGiveOrdersFor(queue.index, from))
 	{
@@ -192,12 +192,12 @@ static void giftAutoGame(uint8_t from, uint8_t to, bool send)
 	{
 		uint8_t subType = AUTOGAME_GIFT;
 
-		NETbeginEncode(NETgameQueue(selectedPlayer), GAME_GIFT);
-		NETuint8_t(&subType);
-		NETuint8_t(&from);
-		NETuint8_t(&to);
-		NETuint32_t(&dummy);
-		NETend();
+		auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_GIFT);
+		NETuint8_t(w, subType);
+		NETuint8_t(w, from);
+		NETuint8_t(w, to);
+		NETuint32_t(w, dummy);
+		NETend(w);
 		debug(LOG_SYNC, "We (%d) are telling %d we want to enable/disable a autogame", from, to);
 	}
 	// If we are receiving the "gift"
@@ -223,12 +223,12 @@ void giftRadar(uint8_t from, uint8_t to, bool send)
 	{
 		uint8_t subType = RADAR_GIFT;
 
-		NETbeginEncode(NETgameQueue(selectedPlayer), GAME_GIFT);
-		NETuint8_t(&subType);
-		NETuint8_t(&from);
-		NETuint8_t(&to);
-		NETuint32_t(&dummy);
-		NETend();
+		auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_GIFT);
+		NETuint8_t(w, subType);
+		NETuint8_t(w, from);
+		NETuint8_t(w, to);
+		NETuint32_t(w, dummy);
+		NETend(w);
 	}
 	// If we are receiving the gift
 	else
@@ -274,9 +274,9 @@ static void recvGiftDroids(uint8_t from, uint8_t to, uint32_t droidID)
 	if (psDroid)
 	{
 		syncDebugDroid(psDroid, '<');
-		giftSingleDroid(psDroid, to, false);
+		bool successfulTransfer = giftSingleDroid(psDroid, to, false) != nullptr;
 		syncDebugDroid(psDroid, '>');
-		if (to == selectedPlayer)
+		if (successfulTransfer && (to == selectedPlayer))
 		{
 			CONPRINTF(_("%s Gives you a %s"), getPlayerName(from), psDroid->aName);
 		}
@@ -294,11 +294,11 @@ static void recvGiftDroids(uint8_t from, uint8_t to, uint32_t droidID)
 // \param to    :player that should be getting the droid
 static void sendGiftDroids(uint8_t from, uint8_t to)
 {
-	DROID        *psD;
+	DroidList::const_iterator psD;
 	uint8_t      giftType = DROID_GIFT;
-	uint8_t      totalToSend;
+	uint8_t      totalToSend = 0;
 
-	if (apsDroidLists[from] == nullptr)
+	if (apsDroidLists[from].empty())
 	{
 		return;
 	}
@@ -309,12 +309,17 @@ static void sendGiftDroids(uint8_t from, uint8_t to)
 	 * over their droid limit.
 	 */
 
-	for (totalToSend = 0, psD = apsDroidLists[from];
-	     psD && getNumDroids(to) + totalToSend < getMaxDroids(to) && totalToSend != UINT8_MAX;
-	     psD = psD->psNext)
+	for (psD = apsDroidLists[from].begin();
+	     psD != apsDroidLists[from].end() && (getNumDroids(to) + totalToSend < getMaxDroids(to)) && totalToSend != UINT8_MAX;
+	     ++psD)
 	{
-		if (psD->selected)
+		if ((*psD)->selected)
 		{
+			if ((*psD)->isTransporter() && !transporterIsEmpty(*psD))
+			{
+				CONPRINTF(_("Tried to give away a non-empty %s - but this is not allowed."), (*psD)->aName);
+				continue;
+			}
 			++totalToSend;
 		}
 	}
@@ -323,23 +328,22 @@ static void sendGiftDroids(uint8_t from, uint8_t to)
 	 * does its own net calls.
 	 */
 
-	for (psD = apsDroidLists[from]; psD && totalToSend != 0; psD = psD->psNext)
+	for (psD = apsDroidLists[from].begin(); psD != apsDroidLists[from].end() && totalToSend != 0; ++psD)
 	{
-		if (isTransporter(psD)
-		    && !transporterIsEmpty(psD))
+		if ((*psD)->selected)
 		{
-			CONPRINTF(_("Tried to give away a non-empty %s - but this is not allowed."), psD->aName);
-			continue;
-		}
-		if (psD->selected)
-		{
-			NETbeginEncode(NETgameQueue(selectedPlayer), GAME_GIFT);
-			NETuint8_t(&giftType);
-			NETuint8_t(&from);
-			NETuint8_t(&to);
+			if ((*psD)->isTransporter() && !transporterIsEmpty(*psD))
+			{
+				continue;
+			}
+
+			auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_GIFT);
+			NETuint8_t(w, giftType);
+			NETuint8_t(w, from);
+			NETuint8_t(w, to);
 			// Add the droid to the packet
-			NETuint32_t(&psD->id);
-			NETend();
+			NETuint32_t(w, (*psD)->id);
+			NETend(w);
 
 			// Decrement the number of droids left to send
 			--totalToSend;
@@ -358,12 +362,12 @@ static void giftResearch(uint8_t from, uint8_t to, bool send)
 	{
 		uint8_t giftType = RESEARCH_GIFT;
 
-		NETbeginEncode(NETgameQueue(selectedPlayer), GAME_GIFT);
-		NETuint8_t(&giftType);
-		NETuint8_t(&from);
-		NETuint8_t(&to);
-		NETuint32_t(&dummy);
-		NETend();
+		auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_GIFT);
+		NETuint8_t(w, giftType);
+		NETuint8_t(w, from);
+		NETuint8_t(w, to);
+		NETuint32_t(w, dummy);
+		NETend(w);
 	}
 	else if (alliancesCanGiveResearchAndRadar(game.alliance))
 	{
@@ -378,7 +382,6 @@ static void giftResearch(uint8_t from, uint8_t to, bool send)
 			if (IsResearchCompleted(&asPlayerResList[from][i])
 			    && !IsResearchCompleted(&asPlayerResList[to][i]))
 			{
-				MakeResearchCompleted(&asPlayerResList[to][i]);
 				researchResult(i, to, false, nullptr, true);
 			}
 		}
@@ -394,12 +397,12 @@ void giftPower(uint8_t from, uint8_t to, uint32_t amount, bool send)
 	{
 		uint8_t giftType = POWER_GIFT;
 
-		NETbeginEncode(NETgameQueue(selectedPlayer), GAME_GIFT);
-		NETuint8_t(&giftType);
-		NETuint8_t(&from);
-		NETuint8_t(&to);
-		NETuint32_t(&amount);
-		NETend();
+		auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_GIFT);
+		NETuint8_t(w, giftType);
+		NETuint8_t(w, from);
+		NETuint8_t(w, to);
+		NETuint32_t(w, amount);
+		NETend(w);
 	}
 	else
 	{
@@ -474,7 +477,6 @@ void requestAlliance(uint8_t from, uint8_t to, bool prop, bool allowAudio)
 void breakAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio)
 {
 	char	tm1[128];
-	STRUCTURE* psStructure;
 
 	if (prop && bMultiMessages)
 	{
@@ -502,7 +504,7 @@ void breakAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio)
 
 	// Make sure p1's structures are no longer considered "our buildings" to their former allies
 	// For unit pathing
-	for (psStructure = apsStructLists[p1]; psStructure; psStructure = psStructure->psNext)
+	for (const STRUCTURE* psStructure : apsStructLists[p1])
 	{
 		StructureBounds b = getStructureBounds(psStructure);
 
@@ -516,7 +518,7 @@ void breakAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio)
 		}
 	}
 	// Do the same for p2's stuff
-	for (psStructure = apsStructLists[p2]; psStructure; psStructure = psStructure->psNext)
+	for (const STRUCTURE* psStructure : apsStructLists[p2])
 	{
 		StructureBounds b = getStructureBounds(psStructure);
 
@@ -533,8 +535,6 @@ void breakAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio)
 
 void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allowNotification)
 {
-	DROID	*psDroid;
-	STRUCTURE	*psStructure;
 	char	tm1[128];
 
 	if (bMultiMessages && prop)
@@ -573,7 +573,7 @@ void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allow
 	}
 
 	// Clear out any attacking orders
-	for (psDroid = apsDroidLists[p1]; psDroid; psDroid = psDroid->psNext)	// from -> to
+	for (DROID* psDroid : apsDroidLists[p1])	// from -> to
 	{
 		if (psDroid->order.type == DORDER_ATTACK
 		    && psDroid->order.psObj
@@ -582,7 +582,7 @@ void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allow
 			orderDroid(psDroid, DORDER_STOP, ModeImmediate);
 		}
 	}
-	for (psDroid = apsDroidLists[p2]; psDroid; psDroid = psDroid->psNext)	// to -> from
+	for (DROID* psDroid : apsDroidLists[p2])	// to -> from
 	{
 		if (psDroid->order.type == DORDER_ATTACK
 		    && psDroid->order.psObj
@@ -593,7 +593,7 @@ void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allow
 	}
 
 	// Properly mark all of p1's structures as allied buildings for unit pathing
-	for (psStructure = apsStructLists[p1]; psStructure; psStructure = psStructure->psNext)
+	for (const STRUCTURE* psStructure : apsStructLists[p1])
 	{
 		StructureBounds b = getStructureBounds(psStructure);
 
@@ -615,7 +615,7 @@ void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allow
 		}
 	}
 	// Do the same for p2's stuff
-	for (psStructure = apsStructLists[p2]; psStructure; psStructure = psStructure->psNext)
+	for (const STRUCTURE* psStructure : apsStructLists[p2])
 	{
 		StructureBounds b = getStructureBounds(psStructure);
 
@@ -641,12 +641,12 @@ void formAlliance(uint8_t p1, uint8_t p2, bool prop, bool allowAudio, bool allow
 
 void sendAlliance(uint8_t from, uint8_t to, uint8_t state, int32_t value)
 {
-	NETbeginEncode(NETgameQueue(selectedPlayer), GAME_ALLIANCE);
-	NETuint8_t(&from);
-	NETuint8_t(&to);
-	NETuint8_t(&state);
-	NETint32_t(&value);
-	NETend();
+	auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_ALLIANCE);
+	NETuint8_t(w, from);
+	NETuint8_t(w, to);
+	NETuint8_t(w, state);
+	NETint32_t(w, value);
+	NETend(w);
 }
 
 bool recvAlliance(NETQUEUE queue, bool allowAudio)
@@ -654,12 +654,12 @@ bool recvAlliance(NETQUEUE queue, bool allowAudio)
 	uint8_t to, from, state;
 	int32_t value;
 
-	NETbeginDecode(queue, GAME_ALLIANCE);
-	NETuint8_t(&from);
-	NETuint8_t(&to);
-	NETuint8_t(&state);
-	NETint32_t(&value);
-	NETend();
+	auto r = NETbeginDecode(queue, GAME_ALLIANCE);
+	NETuint8_t(r, from);
+	NETuint8_t(r, to);
+	NETuint8_t(r, state);
+	NETint32_t(r, value);
+	NETend(r);
 
 	if (!canGiveOrdersFor(queue.index, from))
 	{
@@ -732,8 +732,8 @@ void  technologyGiveAway(const STRUCTURE *pS)
 	}
 
 	int featureIndex;
-	for (featureIndex = 0; featureIndex < numFeatureStats && asFeatureStats[featureIndex].subType != FEAT_GEN_ARTE; ++featureIndex) {}
-	if (featureIndex >= numFeatureStats)
+	for (featureIndex = 0; featureIndex < asFeatureStats.size() && asFeatureStats[featureIndex].subType != FEAT_GEN_ARTE; ++featureIndex) {}
+	if (featureIndex >= asFeatureStats.size())
 	{
 		debug(LOG_WARNING, "No artefact feature!");
 		return;
@@ -764,29 +764,28 @@ void  technologyGiveAway(const STRUCTURE *pS)
  */
 void sendMultiPlayerFeature(uint32_t ref, uint32_t x, uint32_t y, uint32_t id)
 {
-	NETbeginEncode(NETgameQueue(selectedPlayer), GAME_DEBUG_ADD_FEATURE);
+	auto w = NETbeginEncode(NETgameQueue(realSelectedPlayer), GAME_DEBUG_ADD_FEATURE);
 	{
-		NETuint32_t(&ref);
-		NETuint32_t(&x);
-		NETuint32_t(&y);
-		NETuint32_t(&id);
+		NETuint32_t(w, ref);
+		NETuint32_t(w, x);
+		NETuint32_t(w, y);
+		NETuint32_t(w, id);
 	}
-	NETend();
+	NETend(w);
 }
 
 void recvMultiPlayerFeature(NETQUEUE queue)
 {
 	uint32_t ref = 0xff, x = 0, y = 0, id = 0;
-	unsigned int i;
 
-	NETbeginDecode(queue, GAME_DEBUG_ADD_FEATURE);
+	auto r = NETbeginDecode(queue, GAME_DEBUG_ADD_FEATURE);
 	{
-		NETuint32_t(&ref);
-		NETuint32_t(&x);
-		NETuint32_t(&y);
-		NETuint32_t(&id);
+		NETuint32_t(r, ref);
+		NETuint32_t(r, x);
+		NETuint32_t(r, y);
+		NETuint32_t(r, id);
 	}
-	NETend();
+	NETend(r);
 
 	const DebugInputManager& dbgInputManager = gInputManager.debugManager();
 	if (!dbgInputManager.debugMappingsAllowed() && bMultiPlayer)
@@ -796,7 +795,7 @@ void recvMultiPlayerFeature(NETQUEUE queue)
 	}
 
 	// Find the feature stats list that contains the feature type we want to build
-	for (i = 0; i < numFeatureStats; ++i)
+	for (size_t i = 0, end = asFeatureStats.size(); i < end; ++i)
 	{
 		// If we found the correct feature type
 		if (asFeatureStats[i].ref == ref)
