@@ -91,6 +91,8 @@ struct MultiplayOptionsLocked
 	bool bases;
 	bool spectators;
 	bool name;
+	bool readybeforefull;
+	bool cheats;
 
 	bool operator==(const MultiplayOptionsLocked& other) const
 	{
@@ -103,7 +105,9 @@ struct MultiplayOptionsLocked
 			&& position == other.position
 			&& bases == other.bases
 			&& spectators == other.spectators
-			&& name == other.name;
+			&& name == other.name
+			&& readybeforefull == other.readybeforefull
+			&& cheats == other.cheats;
 	}
 };
 const MultiplayOptionsLocked& getLockedOptions();
