@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2020  Warzone 2100 Project
+	Copyright (C) 2005-2025  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -30,4 +30,8 @@ bool applyLimitSet();
 void createLimitSet();
 void resetLimits(void);
 
+#include <functional>
+typedef std::function<void(const std::string& line)> PrintStructureLimitsLineFunc;
+void printStructureLimitsInfo(std::vector<MULTISTRUCTLIMITS>& structureLimits, const PrintStructureLimitsLineFunc& printLineFunc);
+
 #endif //__cplusplus //__INCLUDED_MULTILIMIT_H__
