@@ -27,7 +27,7 @@
 #include <map>
 
 #include "lib/framework/frame.h"
-#include "lib/netplay/netplay.h"
+#include "lib/netplay/sync_debug.h"
 #include "lib/ivis_opengl/imd.h"
 #include "objects.h"
 #include "lib/gamelib/gtime.h"
@@ -50,9 +50,14 @@
 
 // The stores for the research stats
 std::vector<RESEARCH> asResearch;
+optional<ResearchUpgradeCalculationMode> researchUpgradeCalcMode;
+std::unordered_map<WzString, std::vector<size_t>> resCategories;
 nlohmann::json cachedStatsObject = nlohmann::json(nullptr);
 std::vector<wzapi::PerPlayerUpgrades> cachedPerPlayerUpgrades;
 
+typedef std::unordered_map<std::string, std::unordered_map<std::string, int64_t>> RawResearchUpgradeChangeValues;
+std::array<RawResearchUpgradeChangeValues, MAX_PLAYERS> cachedPerPlayerRawUpgradeChange;
+
 //used for Callbacks to say which topic was last researched
 RESEARCH                *psCBLastResearch;
 STRUCTURE				*psCBLastResStructure;
@@ -88,9 +93,9 @@ static bool checkResearchName(RESEARCH *psRes, UDWORD numStats);
 
 //flag that indicates whether the player can self repair
 static UBYTE bSelfRepair[MAX_PLAYERS];
-static void replaceDroidComponent(DROID *pList, UDWORD oldType, UDWORD oldCompInc,
+static void replaceDroidComponent(DroidList& pList, UDWORD oldType, UDWORD oldCompInc,
                                   UDWORD newCompInc);
-static void replaceStructureComponent(STRUCTURE *pList, UDWORD oldType, UDWORD oldCompInc,
+static void replaceStructureComponent(StructureList& pList, UDWORD oldType, UDWORD oldCompInc,
                                       UDWORD newCompInc, UBYTE player);
 static void switchComponent(DROID *psDroid, UDWORD oldType, UDWORD oldCompInc,
                             UDWORD newCompInc);
@@ -105,6 +110,8 @@ bool researchInitVars()
 	psCBLastResStructure = nullptr;
 	CBResFacilityOwner = -1;
 	asResearch.clear();
+	researchUpgradeCalcMode = nullopt;
+	resCategories.clear();
 	cachedStatsObject = nlohmann::json(nullptr);
 	cachedPerPlayerUpgrades.clear();
 	playerUpgradeCounts = std::vector<PlayerUpgradeCounts>(MAX_PLAYERS);
@@ -120,6 +127,12 @@ bool researchInitVars()
 	return true;
 }
 
+ResearchUpgradeCalculationMode getResearchUpgradeCalcMode()
+{
+	// Default to ResearchUpgradeCalculationMode::Compat, unless otherwise specified
+	return researchUpgradeCalcMode.value_or(ResearchUpgradeCalculationMode::Compat);
+}
+
 uint32_t PlayerUpgradeCounts::getNumWeaponImpactClassUpgrades(WEAPON_SUBCLASS subClass)
 {
 	auto subClassStr = getWeaponSubClass(subClass);
@@ -240,10 +253,104 @@ public:
 	}
 };
 
+static bool isResAPrereqForResB(size_t resAIndex, size_t resBIndex)
+{
+	if (resAIndex == resBIndex)
+	{
+		return false;
+	}
+	const RESEARCH *resB = &asResearch[resBIndex];
+	std::deque<const RESEARCH *> stack = {resB};
+	while (!stack.empty())
+	{
+		const RESEARCH *pCurr = stack.back();
+		stack.pop_back();
+		for (auto prereqIndex: pCurr->pPRList)
+		{
+			if (prereqIndex == resAIndex)
+			{
+				return true;
+			}
+			auto prereq = &asResearch[prereqIndex];
+			stack.push_back(prereq);
+		}
+	}
+	return false;
+}
+
+static bool isResearchListValidConnectedDependencyGraph(const std::vector<size_t>& researchIndexes)
+{
+	if (researchIndexes.size() == 0)
+	{
+		return false;
+	}
+
+	std::unordered_map<size_t, size_t> in_degree;
+	std::vector<size_t> source_nodes;
+
+	for (const auto resIdxA : researchIndexes)
+	{
+		for (const auto resIdxB : researchIndexes)
+		{
+			if (isResAPrereqForResB(resIdxA, resIdxB))
+			{
+				in_degree[resIdxA]++;
+			}
+		}
+	}
+
+	for (const auto resIdx : researchIndexes)
+	{
+		if (in_degree.count(resIdx) == 0)
+		{
+			source_nodes.push_back(resIdx);
+		}
+	}
+
+	if (source_nodes.size() != 1)
+	{
+		debug(LOG_WZ, "Category graph has %zu potential source / edge nodes.", source_nodes.size());
+		return false;
+	}
+
+	return true;
+}
+
+static optional<ResearchUpgradeCalculationMode> resCalcModeStringToValue(const WzString& calcModeStr)
+{
+	if (calcModeStr.compare("compat") == 0)
+	{
+		return ResearchUpgradeCalculationMode::Compat;
+	}
+	else if (calcModeStr.compare("improved") == 0)
+	{
+		return ResearchUpgradeCalculationMode::Improved;
+	}
+	else
+	{
+		return nullopt;
+	}
+}
+
+static const char* resCalcModeToString(ResearchUpgradeCalculationMode mode)
+{
+	switch (mode)
+	{
+		case ResearchUpgradeCalculationMode::Compat:
+			return "compat";
+		case ResearchUpgradeCalculationMode::Improved:
+			return "improved";
+	}
+	return "invalid";
+}
+
+#define RESEARCH_JSON_CONFIG_DICT_KEY "_config_"
+
 /** Load the research stats */
 bool loadResearch(WzConfig &ini)
 {
 	ASSERT(ini.isAtDocumentRoot(), "WzConfig instance is in the middle of traversal");
+	const WzString CONFIG_DICT_KEY_STR = RESEARCH_JSON_CONFIG_DICT_KEY;
 	std::vector<WzString> list = ini.childGroups();
 	PLAYER_RESEARCH dummy;
 	memset(&dummy, 0, sizeof(dummy));
@@ -251,6 +358,38 @@ bool loadResearch(WzConfig &ini)
 	preResearch.resize(list.size());
 	for (size_t inc = 0; inc < list.size(); ++inc)
 	{
+		if (list[inc] == CONFIG_DICT_KEY_STR)
+		{
+			// handle the special config dict
+			ini.beginGroup(list[inc]);
+
+			// calculationMode
+			auto calcModeStr = ini.value("calculationMode", resCalcModeToString(ResearchUpgradeCalculationMode::Compat)).toWzString();
+			auto calcModeParsed = resCalcModeStringToValue(calcModeStr);
+			if (calcModeParsed.has_value())
+			{
+				if (!researchUpgradeCalcMode.has_value())
+				{
+					researchUpgradeCalcMode = calcModeParsed.value();
+				}
+				else
+				{
+					if (researchUpgradeCalcMode.value() != calcModeParsed.value())
+					{
+						debug(LOG_ERROR, "Non-matching research JSON calculationModes");
+						debug(LOG_INFO, "Research JSON file \"%s\" has specified a calculationMode (\"%s\") that does not match the first loaded research JSON's calculationMode (\"%s\")", ini.fileName().toUtf8().c_str(), calcModeStr.toUtf8().c_str(), resCalcModeToString(researchUpgradeCalcMode.value()));
+					}
+				}
+			}
+			else
+			{
+				ASSERT_OR_RETURN(false, false, "Invalid _config_ \"calculationMode\" value: \"%s\"", calcModeStr.toUtf8().c_str());
+			}
+
+			ini.endGroup();
+			continue;
+		}
+
 		// HACK FIXME: the code assumes we have empty PLAYER_RESEARCH entries to throw around
 		for (auto &j : asPlayerResList)
 		{
@@ -261,6 +400,7 @@ bool loadResearch(WzConfig &ini)
 		RESEARCH research;
 		research.index = inc;
 		research.name = ini.string("name");
+		research.category = ini.string("category");
 		research.id = list[inc];
 
 		//check the name hasn't been used already
@@ -293,6 +433,18 @@ bool loadResearch(WzConfig &ini)
 			research.keyTopic = 0;
 		}
 
+		//special flag to not reveal research from "give all" and not to research with "research all" cheats
+		unsigned int excludeFromCheats = ini.value("excludeFromCheats", 0).toUInt();
+		ASSERT(excludeFromCheats <= 1, "Invalid excludeFromCheats for research topic - '%s' ", getStatsName(&research));
+		if (excludeFromCheats <= 1)
+		{
+			research.excludeFromCheats = ini.value("excludeFromCheats", 0).toUInt();
+		}
+		else
+		{
+			research.excludeFromCheats = 0;
+		}
+
 		//set tech code
 		UBYTE techCode = ini.value("techCode", 0).toUInt();
 		ASSERT(techCode <= 1, "Invalid tech code for research topic - '%s' ", getStatsName(&research));
@@ -501,6 +653,53 @@ bool loadResearch(WzConfig &ini)
 		return false;
 	}
 
+	// populate research category info
+	resCategories.clear(); // must clear because we re-process the entire asResearch list if loading more than one research file
+	for (size_t inc = 0; inc < asResearch.size(); inc++)
+	{
+		const auto& cat = asResearch[inc].category;
+		if (cat.isEmpty())
+		{
+			continue;
+		}
+		resCategories[cat].push_back(inc);
+	}
+	for (auto it = resCategories.begin(); it != resCategories.end(); /* no increment here */)
+	{
+		auto& membersOfCategory = it->second;
+
+		if (!isResearchListValidConnectedDependencyGraph(membersOfCategory))
+		{
+			debug(LOG_ERROR, "Research category items do not exist on a valid connected dependency graph: \"%s\"", it->first.toUtf8().c_str());
+			for (const auto& inc : membersOfCategory)
+			{
+				asResearch[inc].category.clear();
+			}
+			it = resCategories.erase(it);
+			continue;
+		}
+
+		std::stable_sort(membersOfCategory.begin(), membersOfCategory.end(), [](size_t idxA, size_t idxB) -> bool {
+			return isResAPrereqForResB(idxA, idxB);
+		});
+		uint16_t prog = 1;
+		size_t categorySize = membersOfCategory.size();
+		for (const auto& inc : membersOfCategory)
+		{
+			asResearch[inc].categoryProgress = prog;
+			asResearch[inc].categoryMax = categorySize;
+			prog++;
+		}
+
+		++it;
+	}
+
+	// If the first research json file does not explicitly set calculationMode, default to compat
+	if (!researchUpgradeCalcMode.has_value())
+	{
+		researchUpgradeCalcMode = ResearchUpgradeCalculationMode::Compat;
+	}
+
 	return true;
 }
 
@@ -663,6 +862,14 @@ static inline int64_t iDivCeil(int64_t dividend, int64_t divisor)
 	return (dividend / divisor) + static_cast<int64_t>((dividend % divisor != 0 && hasPosQuotient));
 }
 
+static inline int64_t iDivFloor(int64_t dividend, int64_t divisor)
+{
+	ASSERT_OR_RETURN(0, divisor != 0, "Divide by 0");
+	bool hasNegQuotient = (dividend >= 0) != (divisor >= 0);
+	// C++11 defines the behavior of % to be truncated
+	return (dividend / divisor) - static_cast<int64_t>((dividend % divisor != 0 && hasNegQuotient));
+}
+
 static void eventResearchedHandleUpgrades(const RESEARCH *psResearch, const STRUCTURE *psStruct, int player)
 {
 	if (cachedStatsObject.is_null()) { cachedStatsObject = wzapi::constructStatsObject(); }
@@ -672,6 +879,8 @@ static void eventResearchedHandleUpgrades(const RESEARCH *psResearch, const STRU
 	debug(LOG_RESEARCH, "RESEARCH : %s(%s) for %d", psResearch->name.toUtf8().c_str(), psResearch->id.toUtf8().c_str(), player);
 
 	ASSERT_OR_RETURN(, player >= 0 && player < cachedPerPlayerUpgrades.size(), "Player %d does not exist in per-player upgrades?", player);
+	auto &playerRawUpgradeChangeTotals = cachedPerPlayerRawUpgradeChange[player];
+	const auto upgradeCalcMode = getResearchUpgradeCalcMode();
 
 	PlayerUpgradeCounts tempStats;
 
@@ -789,7 +998,8 @@ static void eventResearchedHandleUpgrades(const RESEARCH *psResearch, const STRU
 						continue;
 					}
 					int64_t currentUpgradesValue = currentUpgradesValue_json.get<int64_t>();
-					int64_t newUpgradesChange = iDivCeil((statsOriginalValueX.get<int64_t>() * value), 100);
+					int64_t scaledChange = (statsOriginalValueX.get<int64_t>() * value);
+					int64_t newUpgradesChange = (value < 0) ? iDivFloor(scaledChange, 100) : iDivCeil(scaledChange, 100);
 					int64_t newUpgradesValue = (currentUpgradesValue + newUpgradesChange);
 					if (currentUpgradesValue_json.is_number_unsigned())
 					{
@@ -820,8 +1030,29 @@ static void eventResearchedHandleUpgrades(const RESEARCH *psResearch, const STRU
 					continue;
 				}
 				int64_t currentUpgradesValue = currentUpgradesValue_json.get<int64_t>();
-				int64_t newUpgradesChange = iDivCeil((statsOriginalValue * value), 100);
-				int64_t newUpgradesValue = (currentUpgradesValue + newUpgradesChange);
+				int64_t scaledChange = (statsOriginalValue * value);
+				int64_t newUpgradesChange = 0;
+				int64_t newUpgradesValue = 0;
+				switch (upgradeCalcMode)
+				{
+					case ResearchUpgradeCalculationMode::Compat:
+						// Default / compat cumulative upgrade handling (the only option for many years - from at least 3.x/(3.2+?)-4.4.2?)
+						// This can accumulate noticeable error, especially if repeatedly upgrading small values by small percentages (commonly impacted: armour, thermal)
+						// However, research.json created and tested during this long period may be expecting this outcome / behavior
+						newUpgradesChange = (value < 0) ? iDivFloor(scaledChange, 100) : iDivCeil(scaledChange, 100);
+						newUpgradesValue = (currentUpgradesValue + newUpgradesChange);
+						break;
+					case ResearchUpgradeCalculationMode::Improved:
+					{
+						// "Improved" cumulative upgrade handling (significantly reduces accumulated errors)
+						auto& compUpgradeTotals = playerRawUpgradeChangeTotals[cname.first];
+						auto& cumulativeUpgradeScaledChange = compUpgradeTotals[parameter];
+						cumulativeUpgradeScaledChange += scaledChange;
+						newUpgradesValue = statsOriginalValue + ((cumulativeUpgradeScaledChange < 0) ? iDivFloor(cumulativeUpgradeScaledChange, 100) : iDivCeil(cumulativeUpgradeScaledChange, 100));
+						newUpgradesChange = newUpgradesValue - currentUpgradesValue;
+						break;
+					}
+				}
 				if (currentUpgradesValue_json.is_number_unsigned())
 				{
 					// original was unsigned integer - round anything less than 0 up to 0
@@ -988,17 +1219,17 @@ void researchResult(UDWORD researchIndex, UBYTE player, bool bDisplay, STRUCTURE
 		int compInc = componentResult->index;
 		makeComponentAvailable(apCompLists[player][type][compInc]);
 		//check for default sensor
-		if (type == COMP_SENSOR && (asSensorStats + compInc)->location == LOC_DEFAULT)
+		if (type == COMP_SENSOR && asSensorStats[compInc].location == LOC_DEFAULT)
 		{
 			aDefaultSensor[player] = compInc;
 		}
 		//check for default ECM
-		else if (type == COMP_ECM && (asECMStats + compInc)->location == LOC_DEFAULT)
+		else if (type == COMP_ECM && asECMStats[compInc].location == LOC_DEFAULT)
 		{
 			aDefaultECM[player] = compInc;
 		}
 		//check for default Repair
-		else if (type == COMP_REPAIRUNIT && (asRepairStats + compInc)->location == LOC_DEFAULT)
+		else if (type == COMP_REPAIRUNIT && asRepairStats[compInc].location == LOC_DEFAULT)
 		{
 			aDefaultRepair[player] = compInc;
 			enableSelfRepair(player);
@@ -1065,12 +1296,18 @@ bool ResearchShutDown()
 void ResearchRelease()
 {
 	asResearch.clear();
+	researchUpgradeCalcMode = nullopt;
+	resCategories.clear();
 	for (auto &i : asPlayerResList)
 	{
 		i.clear();
 	}
 	cachedStatsObject = nlohmann::json(nullptr);
 	cachedPerPlayerUpgrades.clear();
+	for (auto &p : cachedPerPlayerRawUpgradeChange)
+	{
+		p.clear();
+	}
 	playerUpgradeCounts = std::vector<PlayerUpgradeCounts>(MAX_PLAYERS);
 }
 
@@ -1131,10 +1368,9 @@ void releaseResearch(STRUCTURE *psBuilding, QUEUE_MODE mode)
 */
 void CancelAllResearch(UDWORD pl)
 {
-	STRUCTURE	*psCurr;
 	if (pl >= MAX_PLAYERS) { return; }
 
-	for (psCurr = apsStructLists[pl]; psCurr != nullptr; psCurr = psCurr->psNext)
+	for (STRUCTURE* psCurr : apsStructLists[pl])
 	{
 		if (psCurr->pStructureType->type == REF_RESEARCH)
 		{
@@ -1456,11 +1692,8 @@ static void replaceComponent(COMPONENT_STATS *pNewComponent, COMPONENT_STATS *pO
 	//check thru the templates
 	enumerateTemplates(player, replaceComponentInTemplate);
 	// also check build queues
-	STRUCTURE *psNBuilding = nullptr;
-	for (STRUCTURE *psCBuilding = apsStructLists[player]; psCBuilding != nullptr; psCBuilding = psNBuilding)
+	for (STRUCTURE *psCBuilding : apsStructLists[player])
 	{
-		/* Copy the next pointer - not 100% sure if the structure could get destroyed but this covers us anyway */
-		psNBuilding = psCBuilding->psNext;
 		if ((psCBuilding->pStructureType->type == STRUCTURE_TYPE::REF_FACTORY ||
 			psCBuilding->pStructureType->type == STRUCTURE_TYPE::REF_CYBORG_FACTORY ||
 			psCBuilding->pStructureType->type == STRUCTURE_TYPE::REF_VTOL_FACTORY) &&
@@ -1523,7 +1756,7 @@ void researchReward(UBYTE losingPlayer, UBYTE rewardPlayer)
 	UDWORD topicIndex = 0, researchPoints = 0, rewardID = 0;
 
 	//look through the losing players structures to find a research facility
-	for (STRUCTURE *psStruct = apsStructLists[losingPlayer]; psStruct != nullptr; psStruct = psStruct->psNext)
+	for (const STRUCTURE *psStruct : apsStructLists[losingPlayer])
 	{
 		if (psStruct->pStructureType->type == REF_RESEARCH)
 		{
@@ -1581,17 +1814,15 @@ bool selfRepairEnabled(UBYTE player)
 }
 
 /*for a given list of droids, replace the old component if exists*/
-void replaceDroidComponent(DROID *pList, UDWORD oldType, UDWORD oldCompInc,
+void replaceDroidComponent(DroidList& pList, UDWORD oldType, UDWORD oldCompInc,
                            UDWORD newCompInc)
 {
-	DROID   *psDroid;
-
 	//check thru the droids
-	for (psDroid = pList; psDroid != nullptr; psDroid = psDroid->psNext)
+	for (DROID* psDroid : pList)
 	{
 		switchComponent(psDroid, oldType, oldCompInc, newCompInc);
 		// Need to replace the units inside the transporter
-		if (isTransporter(psDroid))
+		if (psDroid->isTransporter())
 		{
 			replaceTransDroidComponents(psDroid, oldType, oldCompInc, newCompInc);
 		}
@@ -1602,12 +1833,9 @@ void replaceDroidComponent(DROID *pList, UDWORD oldType, UDWORD oldCompInc,
 void replaceTransDroidComponents(DROID *psTransporter, UDWORD oldType,
                                  UDWORD oldCompInc, UDWORD newCompInc)
 {
-	DROID       *psCurr;
+	ASSERT(psTransporter->isTransporter(), "invalid unit type");
 
-	ASSERT(isTransporter(psTransporter), "invalid unit type");
-
-	for (psCurr = psTransporter->psGroup->psList; psCurr != nullptr; psCurr =
-	         psCurr->psGrpNext)
+	for (DROID* psCurr : psTransporter->psGroup->psList)
 	{
 		if (psCurr != psTransporter)
 		{
@@ -1616,10 +1844,9 @@ void replaceTransDroidComponents(DROID *psTransporter, UDWORD oldType,
 	}
 }
 
-void replaceStructureComponent(STRUCTURE *pList, UDWORD oldType, UDWORD oldCompInc,
+void replaceStructureComponent(StructureList& pList, UDWORD oldType, UDWORD oldCompInc,
                                UDWORD newCompInc, UBYTE player)
 {
-	STRUCTURE   *psStructure;
 	int			inc;
 
 	// If the type is not one we are interested in, then don't bother checking
@@ -1629,7 +1856,7 @@ void replaceStructureComponent(STRUCTURE *pList, UDWORD oldType, UDWORD oldCompI
 	}
 
 	//check thru the structures
-	for (psStructure = pList; psStructure != nullptr; psStructure = psStructure->psNext)
+	for (STRUCTURE* psStructure : pList)
 	{
 		switch (oldType)
 		{
@@ -1735,7 +1962,7 @@ std::vector<AllyResearch> const &listAllyResearch(unsigned ref)
 			}
 
 			// Check each research facility to see if they are doing this topic. (As opposed to having started the topic, but stopped researching it.)
-			for (STRUCTURE *psStruct = apsStructLists[player]; psStruct != nullptr; psStruct = psStruct->psNext)
+			for (const STRUCTURE *psStruct : apsStructLists[player])
 			{
 				RESEARCH_FACILITY *res = (RESEARCH_FACILITY *)psStruct->pFunctionality;
 				if (psStruct->pStructureType->type != REF_RESEARCH || res->psSubject == nullptr)
