@@ -737,6 +737,8 @@ public:
 	}
 	virtual ~LobbyBrowser();
 
+	void triggerRefresh();
+
 protected:
 	virtual int32_t idealWidth() override;
 	virtual int32_t idealHeight() override;
@@ -814,16 +816,13 @@ static inline LobbyGameInfo lobbyGAMESTRUCTtoLobbyGameInfo(const GAMESTRUCT &lob
 	info.isPrivate = lobbyGame.privateGame != 0;
 	info.limits = lobbyGame.limits;
 
-	if (NETisCorrectVersion(lobbyGame.game_version_major, lobbyGame.game_version_minor))
+	if (lobbyGame.desc.alliances <= ALLIANCE_TYPE_MAX)
 	{
-		if (lobbyGame.desc.alliances <= ALLIANCE_TYPE_MAX)
-		{
-			info.alliancesMode = static_cast<AllianceType>(lobbyGame.desc.alliances);
-		}
-		if (lobbyGame.desc.dwUserFlags[2] <= static_cast<uint32_t>(BLIND_MODE_MAX))
-		{
-			info.blindMode = static_cast<BLIND_MODE>(lobbyGame.desc.dwUserFlags[2]);
-		}
+		info.alliancesMode = static_cast<AllianceType>(lobbyGame.desc.alliances);
+	}
+	if (lobbyGame.desc.dwUserFlags[2] <= static_cast<uint32_t>(BLIND_MODE_MAX))
+	{
+		info.blindMode = static_cast<BLIND_MODE>(lobbyGame.desc.dwUserFlags[2]);
 	}
 
 	info.connectionDesc.emplace_back(JoinConnectionDescription::JoinConnectionType::TCP_DIRECT, lobbyGame.desc.host, lobbyGame.hostPort);
@@ -882,6 +881,11 @@ static WZ_THREAD* NETcreateFindGamesAsyncThread(size_t startingIndex, size_t res
 	return thread;
 }
 
+void LobbyBrowser::triggerRefresh()
+{
+	triggerAsyncGameListFetch();
+}
+
 void LobbyBrowser::triggerAsyncGameListFetch()
 {
 	if (currentFetchThread) { return; }
@@ -999,11 +1003,15 @@ void LobbyBrowser::populateTableFromGameList()
 
 	auto weakSelf = std::weak_ptr<LobbyBrowser>(std::static_pointer_cast<LobbyBrowser>(shared_from_this()));
 
+	bool foundGreaterVersion = false;
+
 	// Populate table with the results
 	for (size_t idx = 0; idx < currentResults.size(); idx++)
 	{
 		const auto& gameInfo = currentResults[idx];
 
+		foundGreaterVersion = foundGreaterVersion || NETisGreaterVersion(gameInfo.netcode_version_major, gameInfo.netcode_version_minor);
+
 		bool isCompatibleGame = NETisCorrectVersion(gameInfo.netcode_version_major, gameInfo.netcode_version_minor);
 		if (filterIncompatible && !isCompatibleGame)
 		{
@@ -1040,7 +1048,7 @@ void LobbyBrowser::populateTableFromGameList()
 			row->setDisabledColor(pal_RGBA(0,0,0,120));
 			WzString tooltip = _("Your version of Warzone is incompatible with this game.");
 			tooltip += "\n";
-			tooltip += WzString::fromUtf8(astringf(_("Host Version: %s"), gameInfo.gameVersionStr.toUtf8().c_str()));
+			tooltip += WzString::format(_("Host Version: %s"), gameInfo.gameVersionStr.toUtf8().c_str());
 			row->setTip(tooltip.toUtf8());
 		}
 		row->addOnClickHandler([weakSelf, idx](W_BUTTON&) {
@@ -1060,7 +1068,7 @@ void LobbyBrowser::populateTableFromGameList()
 		}
 		else
 		{
-			omittedStr = WzString::fromUtf8(astringf(_("(%u omitted)"), static_cast<unsigned int>(currentResults.size())));
+			omittedStr = WzString::format(_("(%u omitted)"), static_cast<unsigned int>(currentResults.size()));
 		}
 
 		if (!filterEmpty && !filterModded)
@@ -1074,7 +1082,7 @@ void LobbyBrowser::populateTableFromGameList()
 			lobbyStatusOverlayWidg->setString(statusStr);
 		}
 
-		if (NET_getLobbyDisabled() || getVersionCheckNewVersionAvailable().value_or(false))
+		if (NET_getLobbyDisabled() || getVersionCheckNewVersionAvailable().value_or(false) || foundGreaterVersion)
 		{
 			lobbyStatusOverlayWidg->setString(_("There appears to be a game update available!"));
 		}
@@ -1291,7 +1299,7 @@ int32_t LobbyBrowser::idealWidth()
 
 int32_t LobbyBrowser::idealHeight()
 {
-	return 600;
+	return 700;
 }
 
 #define WZLOBBY_TABLE_COL_PADDING_X 5
@@ -1440,6 +1448,14 @@ std::shared_ptr<WIDGET> makeLobbyBrowser(const std::function<void()>& onBackButt
 	return LobbyBrowser::make(onBackButtonFunc);
 }
 
+bool refreshLobbyBrowser(const std::shared_ptr<WIDGET>& lobbyBrowserWidg)
+{
+	auto lobbyBrowser = std::dynamic_pointer_cast<LobbyBrowser>(lobbyBrowserWidg);
+	ASSERT_OR_RETURN(false, lobbyBrowser != nullptr, "Not a LobbyBrowser");
+	lobbyBrowser->triggerRefresh();
+	return true;
+}
+
 // Needed because of current lobby server (which uses TCP connections / connection provider)
 // Ensure that all pending fetches have finished (before anything might clean up the connection provider)
 void shutdownLobbyBrowserFetches()
