@@ -1041,14 +1041,23 @@ void transporterAddDroid(DROID *psTransporter, DROID *psDroidToAdd)
 			// search for the nearest transporter if the current one is already full
 			for (auto psOtherDroid : apsDroidLists[psTransporter->player])
 			{
-				if (psOtherDroid->isTransporter() && checkTransporterSpace(psOtherDroid, psDroidToAdd) &&
+				if (psOtherDroid->isTransporter() &&
+					checkTransporterSpace(psOtherDroid, psDroidToAdd) &&
 					droidSqDist(psOtherDroid, psTransporter) < MAX_NEAREST_TRANSPORT_SQ_DIST)
 				{
+					if (psOtherDroid->droidType == DROID_TRANSPORTER && !psDroidToAdd->isCyborg())
+					{
+						continue; // Only send cyborgs to a cyborg transporter.
+					}
 					orderDroidObj(psDroidToAdd, DORDER_EMBARK, psOtherDroid, ModeQueue);
 					return;
 				}
 			}
 		}
+		if (!onMission && psDroidToAdd->isVtol())
+		{
+			moveStopDroid(psDroidToAdd); // So VTOLs are put into a MOVEHOVER status from the prior moveReallyStopDroid() in order.cpp's embark section.
+		}
 		if (psTransporter->player == selectedPlayer)
 		{
 			audio_PlayBuildFailedOnce();
